Package: iheiddown
Title: For Writing Geneva Graduate Institute Documents
Description: A set of tools for writing documents
    according to Geneva Graduate Institute conventions and regulations.
    The most common use is for writing and compiling theses or thesis
    chapters, as drafts or for examination with correct preamble formatting. 
    However, the package also offers users to create HTML presentation
    slides with 'xaringan', complete problem sets, format posters, and, 
    for course instructors, prepare a syllabus.
    The package includes additional functions for institutional color palettes,
    an institutional 'ggplot' theme, a function for counting manuscript words,
    and a bibliographical analysis toolkit.
Date: 2026-05-07
Version: 0.9.9
Authors@R: 
    c(person(given = "James",
           family = "Hollway",
           role = c("aut", "cre", "cph"),
           email = "james.hollway@graduateinstitute.ch",
           comment = c(ORCID = "0000-0002-8361-9647")),
      person(given = "Bernhard",
           family = "Bieri",
           role = "ctb",
           email = "bernhard.bieri@graduateinstitute.ch",
           comment = c(ORCID = "0000-0001-5943-9059")),
      person(given = "Henrique",
           family = "Sposito",
           role = "ctb",
           comment = c(ORCID = "0000-0003-3420-6085"))
    )
URL: https://github.com/iheid-library/iheiddown
BugReports: https://github.com/iheid-library/iheiddown/issues
Depends: R (>= 3.5.0)
License: MIT + file LICENSE
Imports: bookdown, dplyr, ggplot2 (>= 3.4.0), rmarkdown, xaringan,
        crayon, pdftools, rlang, servr, readr, rstudioapi, tibble,
        tidytext, bib2df, stringr, fs, usethis, gender, pagedown
Encoding: UTF-8
RoxygenNote: 7.3.3
Suggests: testthat, kableExtra, knitr, DT, leaflet, remotes,
        modelsummary, gt
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2026-05-07 19:05:45 UTC; hollway
Author: James Hollway [aut, cre, cph] (ORCID:
    <https://orcid.org/0000-0002-8361-9647>),
  Bernhard Bieri [ctb] (ORCID: <https://orcid.org/0000-0001-5943-9059>),
  Henrique Sposito [ctb] (ORCID: <https://orcid.org/0000-0003-3420-6085>)
Maintainer: James Hollway <james.hollway@graduateinstitute.ch>
Repository: CRAN
Date/Publication: 2026-05-08 07:31:53 UTC
Built: R 4.5.2; ; 2026-05-08 11:06:14 UTC; unix

Package: iheiddown
Title: For Writing Geneva Graduate Institute Documents
Description: A set of tools for writing documents
    according to Geneva Graduate Institute conventions and regulations.
    The most common use is for writing and compiling theses or thesis
    chapters, as drafts or for examination with correct preamble formatting. 
    However, the package also offers users to create HTML presentation
    slides with 'xaringan', complete problem sets, format posters, and, 
    for course instructors, prepare a syllabus.
    The package includes additional functions for institutional color palettes,
    an institutional 'ggplot' theme, a function for counting manuscript words,
    and a bibliographical analysis toolkit.
Date: 2026-05-07
Version: 0.9.9
Authors@R: 
    c(person(given = "James",
           family = "Hollway",
           role = c("aut", "cre", "cph"),
           email = "james.hollway@graduateinstitute.ch",
           comment = c(ORCID = "0000-0002-8361-9647")),
      person(given = "Bernhard",
           family = "Bieri",
           role = "ctb",
           email = "bernhard.bieri@graduateinstitute.ch",
           comment = c(ORCID = "0000-0001-5943-9059")),
      person(given = "Henrique",
           family = "Sposito",
           role = "ctb",
           comment = c(ORCID = "0000-0003-3420-6085"))
    )
URL: https://github.com/iheid-library/iheiddown
BugReports: https://github.com/iheid-library/iheiddown/issues
Depends: R (>= 3.5.0)
License: MIT + file LICENSE
Imports: bookdown, dplyr, ggplot2 (>= 3.4.0), rmarkdown, xaringan,
        crayon, pdftools, rlang, servr, readr, rstudioapi, tibble,
        tidytext, bib2df, stringr, fs, usethis, gender, pagedown
Encoding: UTF-8
RoxygenNote: 7.3.3
Suggests: testthat, kableExtra, knitr, DT, leaflet, remotes,
        modelsummary, gt
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2026-05-07 19:05:45 UTC; hollway
Author: James Hollway [aut, cre, cph] (ORCID:
    <https://orcid.org/0000-0002-8361-9647>),
  Bernhard Bieri [ctb] (ORCID: <https://orcid.org/0000-0001-5943-9059>),
  Henrique Sposito [ctb] (ORCID: <https://orcid.org/0000-0003-3420-6085>)
Maintainer: James Hollway <james.hollway@graduateinstitute.ch>
Repository: CRAN
Date/Publication: 2026-05-08 07:31:53 UTC
Built: R 4.5.2; ; 2026-05-08 09:50:02 UTC; unix

# Generated by roxygen2: do not edit by hand

S3method(print,palette)
export(advdate)
export(bookdown_profile)
export(chapter_pdf)
export(count_words)
export(count_words2)
export(iheid_palette)
export(iheid_palettes)
export(iheiddown_betterland)
export(iheiddown_betterport)
export(iheiddown_poster)
export(mean_pages)
export(mean_year)
export(percent_female)
export(preview_start)
export(preview_stop)
export(problemset_pdf)
export(syllabus_pdf)
export(theme_iheid)
export(thesis_pdf)
export(total_pages)
import(crayon)
import(dplyr)
importFrom(bib2df,bib2df)
importFrom(bookdown,pdf_book)
importFrom(bookdown,preview_chapter)
importFrom(bookdown,render_book)
importFrom(fs,path_dir)
importFrom(ggplot2,element_blank)
importFrom(ggplot2,element_line)
importFrom(ggplot2,element_rect)
importFrom(ggplot2,element_text)
importFrom(ggplot2,margin)
importFrom(ggplot2,theme)
importFrom(grDevices,rgb)
importFrom(graphics,image)
importFrom(graphics,par)
importFrom(graphics,rect)
importFrom(graphics,text)
importFrom(pdftools,pdf_text)
importFrom(readr,read_lines)
importFrom(rlang,.data)
importFrom(rmarkdown,pdf_document)
importFrom(rstudioapi,getSourceEditorContext)
importFrom(servr,daemon_list)
importFrom(servr,daemon_stop)
importFrom(stats,na.omit)
importFrom(stringr,str_detect)
importFrom(stringr,str_split)
importFrom(tibble,as_tibble)
importFrom(tidytext,unnest_tokens)
importFrom(usethis,ui_info)
importFrom(utils,file.edit)
importFrom(utils,install.packages)
importFrom(xaringan,inf_mr)

# iheiddown

<img src="man/figures/iheiddown.png" align="right" width="220"/>

<!-- badges: start -->

[![Lifecycle:
maturing](https://img.shields.io/badge/lifecycle-maturing-blue.svg)](https://lifecycle.r-lib.org/articles/stages.html#maturing)
![CRAN/METACRAN](https://img.shields.io/cran/v/iheiddown) ![GitHub
release (latest by
date)](https://img.shields.io/github/v/release/jhollway/iheiddown)
![GitHub Release
Date](https://img.shields.io/github/release-date/jhollway/iheiddown)
![GitHub
issues](https://img.shields.io/github/issues-raw/jhollway/iheiddown)
<!-- [![HitCount](http://hits.dwyl.com/jhollway/iheiddown.svg)](http://hits.dwyl.com/jhollway/iheiddown) -->
[![Codecov test
coverage](https://codecov.io/gh/jhollway/iheiddown/branch/main/graph/badge.svg)](https://app.codecov.io/gh/jhollway/iheiddown?branch=main)
[![CodeFactor](https://www.codefactor.io/repository/github/iheid-library/iheiddown/badge/main)](https://www.codefactor.io/repository/github/iheid-library/iheiddown/overview/main)
<!-- ![GitHub All Releases](https://img.shields.io/github/downloads/jhollway/iheiddown/total) -->
<!-- badges: end -->

## Table of Contents

-   [iheiddown](#iheiddown)
    -   [Write your dissertation](#write-your-dissertation)
    -   [But not only !](#but-not-only-!)
    -   [Installation](#installation)
    -   [Quick start guide](#quick-start-guide)
    -   [Feedback](#feedback)

`{iheiddown}` is a package that provides templates for writing documents
in styles consistent with the Geneva Graduate Institute/ Institut de
Hautes Etudes Internationales et du Developpement (IHEID) in (R)
markdown.

The main use case for `{iheiddown}` is for writing a **Masters or PhD
Dissertation at IHEID**, as it offers a user-friendly, simple, and
straightforward way to write a well-formatted and consistent
dissertation that weaves together argument, evidence, and
interpretation. However, it also integrates templates for creating IHEID
themed presentations powered by
[`{xaringan}`](https://github.com/yihui/xaringan) as well as a template
for IHEID course syllabi.

## Write your dissertation

The package is built upon the [IHEID LaTeX dissertation
template](https://github.com/iheid-library/iheidmytex), which offers versus
common word processors:

-   less prone to corruption or crashing
-   more internal consistency
-   ensured consistency with the IHEID dissertation and other
    guidelines, e.g. dedication, abstract, abbreviations, tables of
    contents, figures, and tables
-   automatic figure and table referencing
-   automatic compilation of your references and bibliography (under
    different styles)
-   compilation chapter-by-chapter (for sending to your supervisor) or
    whole dissertation (for submission)
-   cross-referencing
-   smaller files
-   automatic versioning
-   and much more!

Though you may have never had problems using Word in the past, the size
and structure of most theses tax Word’s capabilities.

However, `{iheiddown}` helps you avoid the need to (learn how to) write
in LaTeX. LaTeX can be daunting for first time users, and many users
often feel it would only pay off if they were writing very complex
dissertations. `{iheiddown}` allows students to write their
dissertations in *RMarkdown*.
[*Markdown*](https://www.markdownguide.org) is a simple and easy-to-use
way to ‘markup’ parts of plain text as headings, **bold** or *italics*
(and much more) in ways that remain very readable and thus editable as
you write. `{iheiddown}`, R, and LaTeX do the work to turn this into a
beautiful dissertation. You write in minimally marked-up plain text and
you get a correctly-formatted dissertation out at the end.

But wait, there’s more! Because `{iheiddown}` is an **R** package, it
especially shines for those who are analysing data.
[R](https://www.r-project.org) is a *free* statistical programme and
language that has a *huge* range of packages available for most current
methods of analysis and visualisation. [RStudio](https://posit.co/) is a
typical frontend that makes working in **R** and especially with
`{iheiddown}` easy. So though `{iheiddown}` is especially attractive to
those writing dissertations with many tables and figures, the
user-friendly nature and pretty output should make it of great benefit
to nearly anyone writing a thesis project.

You can see an example of the kind of dissertation output on the package
website.

## But not only !

Not quite done yet, there is even more! Take a look at the following
table for all available templates:

| Templates                                                       | Format                       | Status                |
|-----------------------------------------------------------------|------------------------------|-----------------------|
| Thesis                                                          | PDF                          | :thumbsup:            |
| Syllabus                                                        | PDF                          | :thumbsup:            |
| [`{xaringan}`](https://github.com/yihui/xaringan) presentations | HTML (can be printed to PDF) | :thumbsup:            |
| Problem set                                                     | PDF                          | :thumbsup:            |
| Posters                                                         | HTML (+ print to PDF)        | :star2: :new: :star2: |
| *Your idea*                                                     | *Open a PR!*                 | :sparkles:            |

## Installation

### Prerequisites

You will first need to install the following software on your
system<sup>[2](#myfootnote2)</sup>:

-   [R](https://cran.r-project.org)
-   [RStudio version 1.2 or
    higher](https://posit.co/download/rstudio-desktop#download), and
-   [LaTeX](https://www.latex-project.org/get/) or
    [MiKTeX](https://miktex.org/howto/install-miktex/)<sup>[1](#myfootnote1)</sup>

### Installing the Stable Version

The easiest way to install the latest stable version of `{iheiddown}` is
via CRAN. Simply open the R console and enter the following to install
and load `{iheiddown}`

``` r
install.packages('iheiddown')
library(iheiddown)
```

That’s it! `iheiddown` is now installed and ready to go.

### Installing the Development Version

To get access to the latest features, you may want to install the
development version of the package.

An easy way of getting access to this version is to install the latest
main version of `{iheiddown}` from Github. To do that, please install
the `{remotes}` package from CRAN and then enter the following commands
into the console:

-   For latest stable version:
    `remotes::install_github("jhollway/iheiddown")`
-   For latest development version:
    `remotes::install_github("jhollway/iheiddown@develop")`

Alternatively, you can find the binaries for all major OSes – Windows,
Mac, and Linux – by looking up the latest release of the package
[here](https://github.com/iheid-library/iheiddown/releases/latest). Manually
download the appropriate binary for your operating system, and install
using an adapted version of the following commands:

-   For Windows:
    `install.packages("~/Downloads/iheiddown_winOS.zip", repos = NULL)`
-   For Mac:
    `install.packages("~/Downloads/iheiddown_macOS.tgz", repos = NULL)`
-   For Unix:
    `install.packages("~/Downloads/iheiddown_linuxOS.tar.gz", repos = NULL)`

## Quick start guide

`{iheiddown}`, among other things, sets up a thesis template that you
can then modify for your dissertation. It’s very easy to get started!

Since the process is similar for theses, presentations, problem sets and
syllabi let us take a look at how to set up a thesis project.

1.  Open RStudio (if it is not already).
2.  Click the new document symbol at the very top left and choose
    `R Markdown...`.
3.  Then from the options on the left `From Template`.
4.  Scroll down through the options on the right until you find
    `Thesis   {iheiddown}`.
5.  Name your thesis project `index`, i.e. your main `.Rmd` should be
    named `index.Rmd`
6.  Select where the project should be saved on your hard drive.

Congratulations! You have now set up your first thesis project. For a
more detailed walkthrough of the different functionalities and how to
get started with each one, please check out the different articles on
the [package website](https://iheid-library.github.io/iheiddown/).

## Feedback

Please [raise an issue](https://github.com/iheid-library/iheiddown/issues)
for this repo if you encounter any bugs or if you have any feature
requests. You can also vote on existing issues that you would like to
see addressed soon. If you would like to contribute to the repo, please
fork this repository and open a pull request when your changes are
ready, or [get in touch with me](https://jameshollway.com) directly.

<sup><a name="myfootnote1">1</a></sup> For Windows users, make sure you
have the latest MiKTeX version installed on you computer. From the
MiKTeX console, you should regularly check for updates as “MiKTeX user
mode”, this will prevent issues when generating your pdf document from
your Markdown template.  
<sup><a name="myfootnote2">2</a></sup> Note that, for unclear reasons,
Yihui Xie’s [TinyTeX](https://yihui.org/tinytex/) is causing trouble.
Try `tinytex::uninstall_tinytex()` and install a local copy.
Unfortunately, full LaTeX installations are *large*.

## ----global.options, include = FALSE------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>",
  fig.align = 'center',
  fig.width=6,
  fig.height=4
)

## ----setup, include=FALSE-----------------------------------------------------
pkgs <- c("iheiddown", "magrittr", "ggplot2")
lapply(pkgs, library, character.only = TRUE)

## ----eval = F, echo = T-------------------------------------------------------
# # Install the required packages
# install.packages("iheiddown")
# remotes::install_github("yihui/xaringan")
# install.packages("servr") # This will allow us to see the slides we are editing
# 
# # Load the packages in your session
# pkgs <- c("iheiddown", "xaringan", "servr")
# lapply(pkgs, library, character.only = TRUE)

## ----echo = FALSE, out.width="80%", fig.cap="Step 1: Open a project"----------
  knitr::include_graphics("images/presentations/0-OpenProject.png", dpi = 144)

## ----echo = FALSE, out.width="80%", fig.cap="Step 2: Select a template"-------
  knitr::include_graphics("images/presentations/1-SelectTemplate.png", dpi = 144)

## ----eval=FALSE, echo=TRUE----------------------------------------------------
# # Install/Load the servr package if you haven't done it already
# install.packages("servr")
# library(servr)
# 
# # Serve your {xaringan} presentation to see live updates when you edit
# iheiddown::preview_start()
# 
# # Close the connection to the live rendering when you're done
# iheiddown::preview_stop()

## ----echo = TRUE, eval = F----------------------------------------------------
# install.packages("RefManageR")

## ----eval=FALSE, echo = TRUE--------------------------------------------------
# # Initializes the bibliography
# library(RefManageR)
# BibOptions(check.entries = FALSE,
#            bib.style = "authoryear", # Bibliography style
#            max.names = 3, # Max author names displayed in bibliography
#            sorting = "nyt", #Name, year, title sorting
#            cite.style = "authoryear", # citation style
#            style = "markdown",
#            hyperlink = FALSE,
#            dashed = FALSE)
# myBib <- ReadBib("myBib.bib", check = FALSE)
# # Note: don't forget to clear the knitr cache to account for changes in the
# # bibliography.

## ----global.options, include = FALSE------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>",
  fig.align = 'center',
  fig.width = 6,
  fig.height = 4
)

## ----setup, include=FALSE-----------------------------------------------------
pkgs <- c("iheiddown", "magrittr", "ggplot2")
lapply(pkgs, library, character.only = TRUE)

## ----echo = FALSE, out.width="80%", fig.cap="Step 1: Open a project"----------
  knitr::include_graphics("images/problemset/0-Open_Project.png", dpi = 144)

## ----echo = FALSE, out.width="80%", fig.cap="Step 2: Select a template"-------
  knitr::include_graphics("images/problemset/1-Create_PS.png", dpi = 144)

## ----global.options, include = FALSE------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>",
  fig.align = 'center',
  fig.width = 6,
  fig.height = 4
)

## ----setup, include=FALSE-----------------------------------------------------
pkgs <- c("iheiddown", "magrittr", "ggplot2")
lapply(pkgs, library, character.only = TRUE)

## ----echo = FALSE, out.width="80%", fig.cap="Step 1: Open a project"----------
  knitr::include_graphics("images/thesis/0-OpenProject.png", dpi = 144)

## ----echo = FALSE, out.width="80%", fig.cap="Step 2: Select a template"-------
  knitr::include_graphics("images/thesis/1-CreateThesis.png", dpi = 144)

.onAttach <- function(libname, pkgname) {
  packageStartupMessage(crayon::red(pkgname, " for IHEID\n",
                                    "Version ",
                                    utils::packageVersion("iheiddown"),
    " created on ",
    utils::packageDescription("iheiddown", fields = "Date"),
    "\n"
  )
  )
}

utils::globalVariables(c("value", "is_code", "start_end", "start_comment", "end_comment"))

#' Advance dates by week
#'
#' @description This function takes a start date, e.g. of a course,
#' and advances it by a number of weeks.
#' This function is used in the syllabus template.
#' @param startdate The first date in the series (e.g. first day of class).
#' @param week The number of weeks into the series.
#' Week 1 is the first date in the series.
#' @return A vector of dates in the format "dd mmm" in parentheses.
#' @examples
#' advdate("2021-06-23", 1:3)
#' @export
advdate <- function(startdate, week) {
  zadv <- as.Date(startdate) + 7 * (week - 1)
  tmp <- paste0("(", trimws(format(zadv, format = "%e %b")), ")")
  return(tmp)
}

#' Creates an R Markdown PDF Syllabus document
#'
#' This is a function called in output in the YAML of the driver Rmd file
#' to specify using the IHEID Syllabus LaTeX template file.
#'
#' @export
#'
#' @param ... Instructions passed to the function from a correctly specified
#' .Rmd document
#' @param input The name of the .Rmd file to serve as input.
#' @importFrom rmarkdown pdf_document
#' @return A modified \code{pdf_document} based on the IHEID Syllabus LaTeX
#'   template, automatically named by course and date.
#' @examples
#' \dontrun{
#' output:
#'   iheiddown::syllabus_pdf:
#'     input: "Untitled.Rmd" 
#'     # Replace with whatever the name of this file is, e.g. "MINT001.Rmd"
#' }
syllabus_pdf <- function(input, ...) {
  code <- readLines(input)
  code <- code[grepl("^code:", code)]
  code <- strsplit(code, " ")[[1]][2]
  # Set base format
  output_format <- rmarkdown::pdf_document(
    latex_engine = "xelatex",
    template = system.file("rmarkdown",
                           "templates",
                           "syllabus_pdf",
                           "resources",
                           "template.tex",
                           package = "iheiddown"))
  # Add lua filter
  output_format$pandoc$lua_filters <- c(
    rmarkdown::pandoc_path_arg(rmarkdown::pkg_file_lua(filters = "color-text.lua",
                                                      package = "iheiddown")), 
    output_format$pandoc$lua_filters)
  # Render stuff
  rmarkdown::render(input,
                    output_file = paste0(code, "_Syllabus_", Sys.Date()),
                    ...,
                    output_format = output_format)
                      
}

# Testing that the problem set rendering works
# 
# Still need to install miktex or some stuff on all runners before running these
# tests
# test_that("syllabus_pdf() works", {
#   # Setup
#   rmarkdown::draft(file = paste0(test_path(), "/UntitledPS"), template = "syllabus",
#                    package = "iheiddown", create_dir = TRUE, edit = FALSE)
#   setwd(paste0(test_path(), "/UntitledPS"))
#   iheiddown::problemset_pdf("UntitledPS.Rmd")
#   # Test
#   expect_true(file.exists(paste0("MINT001_ProblemSet_", Sys.Date(), ".pdf")))
#   # Clean
#   setwd("../../..")
#   unlink(paste0(test_path(), "/UntitledPS"), recursive = TRUE)
# })

#' Posterdown inspired HTML posters
#' 
#' These functions render different versions of the original `{posterdown}`
#' templates with a little IHEID twist to them. All exports are in HTML format.
#' You can save them by printing them to PDF via a modern browser.
#'
#' @param ... Additional arguments to `rmarkdown::html_document`
#' @param template Additional argument passed to `pagedown::poster_relaxed`.
#' IHEID poster templates by default.
#' @param css Additional argument passed to `pagedown::poster_relaxed`.
#' NULL by default.
#' @source [`{Posterdown}`](https://github.com/brentthorne/posterdown)
#' @return R Markdown output format to pass to
#'   [rmarkdown::render()]
#'
#' @examples
#' \dontrun{
#' file <- file.path(tempdir(),"foo.rmd")
#' rmarkdown::draft(file, template="iheiddown_poster", package="iheiddown")
#' }
#' @name posterdown_html
NULL

#' @rdname posterdown_html 
#' @export
iheiddown_poster <- function(...,
	template = system.file("rmarkdown",
	                       "templates",
	                       "iheiddown_poster",
	                       "resources",
	                       "template.html",
	                       package = "iheiddown"), 
	css = NULL) {
	pagedown::poster_relaxed(...,
	                         css = css,
	                         template = template)
}

#' @description The output format `poster_betterland()` mimics the style of the
#' BetterPoster movement from twitter with an IHEID twist.
#' @rdname posterdown_html
#' @export
iheiddown_betterland <- function(...,
                            template = system.file("rmarkdown",
                                                   "templates",
                                                   "iheiddown_betterland",
                                                   "resources",
                                                   "template.html",
                                                   package = "iheiddown"),
                            css = NULL) {
  pagedown::poster_relaxed(...,
                           css = css,
                           template = template)
}

#' @description The output format `poster_betterport()` mimics the style of the
#' BetterPoster movement from twitter with an IHEID twist.
#' @rdname posterdown_html
#' @export
iheiddown_betterport <- function(...,
                                  template = system.file("rmarkdown",
                                                         "templates",
                                                         "iheiddown_betterport",
                                                         "resources",
                                                         "template.html",
                                                         package = "iheiddown"),
                                  css = NULL) {
  pagedown::poster_relaxed(...,
                           css = css,
                           template = template)
}

# Testing that the problem set rendering works
# 
# Still need to install miktex or some stuff on all runners before running these
# tests
# 
# Strange error when rendering that only occurs within tests. Linked to some
# toc? However we do not generate one in these templates...
# 
# test_that("iheiddown_poster() works", {
#   # Setup
#   rmarkdown::draft(file = paste0(test_path(), "/UntitledPoster"),
#                    template = "iheiddown_poster",
#                    package = "iheiddown", create_dir = TRUE, edit = FALSE)
#   setwd(paste0(test_path(), "/UntitledPoster"))
#   iheiddown::iheiddown_poster("UntitledPoster.Rmd")
#   # Test
#   expect_true(file.exists("UntitledPoster.html"))
#   # Clean
#   setwd("../../..")
#   unlink(paste0(test_path(), "/UntitledPoster"), recursive = TRUE)
# })
# 
# test_that("iheiddown_betterland() works", {
#   # Setup
#   rmarkdown::draft(file = paste0(test_path(), "/UntitledPoster"),
#                    template = "iheiddown_betterland",
#                    package = "iheiddown", create_dir = TRUE, edit = FALSE)
#   setwd(paste0(test_path(), "/UntitledPoster"))
#   iheiddown::iheiddown_poster("UntitledPoster.Rmd")
#   # Test
#   expect_true(file.exists("UntitledPoster.html"))
#   # Clean
#   setwd("../../..")
#   unlink(paste0(test_path(), "/UntitledPoster"), recursive = TRUE)
# })
# 
# test_that("iheiddown_betterport() works", {
#   # Setup
#   rmarkdown::draft(file = paste0(test_path(), "/UntitledPoster"),
#                    template = "iheiddown_betterport",
#                    package = "iheiddown", create_dir = TRUE, edit = FALSE)
#   setwd(paste0(test_path(), "/UntitledPoster"))
#   iheiddown::iheiddown_poster("UntitledPoster.Rmd")
#   # Test
#   expect_true(file.exists("UntitledPoster.html"))
#   # Clean
#   setwd("../../..")
#   unlink(paste0(test_path(), "/UntitledPoster"), recursive = TRUE)
# })

# #' @rdname bibstats
# #' @importFrom stringr str_replace_all str_replace fixed
# #' @importFrom bib2df bib2df df2bib
# #' @importFrom purrr map
# #' @export
# fix_bib <- function(bib_file) {
#   if (missing(bib_file)) bib_file <- find_bib()
#   bib <- suppressMessages(bib2df::bib2df(bib_file))
#   bib$PAGES <- stringr::str_replace_all(bib$PAGES,
#                                         stringr::fixed("{\\textendash}"), "--")
#   bib$AUTHOR <- purrr::map(bib$AUTHOR, function(x) {
#     x <- stringr::str_replace(x, "^", "{")
#     x <- stringr::str_replace(x, "\\{\\{", "{")
#     x <- stringr::str_replace(x, "$", "}")
#     x <- stringr::str_replace(x, "\\}\\}", "}")
#   })
#   bib$EDITOR <- purrr::map(bib$EDITOR, function(x) {
#     x <- stringr::str_replace(x, "^", "{")
#     x <- stringr::str_replace(x, "\\{\\{", "{")
#     x <- stringr::str_replace(x, "$", "}")
#     x <- stringr::str_replace(x, "\\}\\}", "}")
#   })
#   bib2df::df2bib(bib, bib_file)
# }

get_used_bib <- function(bib_file, rmd_file) {
  if (missing(bib_file)) bib_file <- find_bib()
  if (missing(rmd_file)) rmd_file <- rstudioapi::getSourceEditorContext()$path
  bib <- suppressMessages(bib2df::bib2df(bib_file))
  current_bibs <- readr::read_lines(rmd_file) %>%
    tibble::as_tibble() %>%
    remove_front_matter() %>%
    remove_code_chunks() %>%
    remove_inline_code() %>%
    remove_html_comment() %>%
    remove_bullets() %>%
    get_biblines() %>%
    dplyr::mutate(value = stringr::str_remove(value, "@")) %>%
    select(value) %>%
    as.vector()
  current_bibs$value
}

remove_bullets <- function(x) {
  dplyr::mutate(x, value = stringr::str_remove(value, "^-[:space:]+"))
}

get_biblines <- function(x) {
  dplyr::filter(x, grepl("@", value))
}

#' Reporting bibliographic statistics
#' 
#' These functions are useful for calculating salient statistics
#' on the bibliographies used for dissertations or syllabi. They include the
#' following functions/metrics:
#' 
#' \describe{
#'   \item{`percent_female()`}{Displays the percentage of authors in a
#'   `.bib` file that are female. See the `{gender}` package for more details.}
#'   \item{`mean_year()`}{Displays the average year of publication of the items
#'   in a given `.bib` file.}
#'   \item{`mean_pages()`}{Displays the average number of pages of the items
#'   in a given `.bib` file.}
#'   \item{`total_pages()`}{Displays the total number of pages of all items
#'   in a given `.bib` file.}
#' }
#' @name bibstats
#' @param bib_file A .bib file for the project.
#' If not given, the functions will search for a .bib file in the folder
#' associated with the file the source editor has open.
#' @param rmd_file A .rmd file
#' If not given, the functions will check to see whether the
#' current file open in the source editor is an .rmd file,
#' and if so use that.
#' @param by A string in c("author", "publication") which determines if the
#' percentage of female authors is computed across all papers or the percentage
#' represents the proportion of papers written by at least one woman.
#' @importFrom bib2df bib2df
#' @importFrom utils install.packages
#' @return Prints a summary statistic (e.g. mean or proportion)
NULL

#' @rdname bibstats
#' @export
percent_female <- function(bib_file,
                           rmd_file,
                           by = c("author", "publication")) {
  
  if (missing(bib_file)) bib_file <- find_bib()
  if (missing(rmd_file)) rmd_file <- rstudioapi::getSourceEditorContext()$path
  by <- match.arg(by, c("author", "publication"))
  # if (!requireNamespace("genderdata", quietly = TRUE)) {
  #   if (!requireNamespace("remotes", quietly = TRUE)) {
  #     utils::install.packages("remotes")
  #   }
  #   remotes::install_github("lmullen/genderdata")
  # }
  bib <- suppressWarnings(bib2df::bib2df(bib_file))
  if (!missing(rmd_file)) {
    used <- get_used_bib(bib_file, rmd_file)
    bib <- dplyr::filter(bib, .data$BIBTEXKEY %in% used)
  }
  authors <- bib$AUTHOR
  gender <- NULL
  # Total percentage of women
  if (by == "author") {
    authors <- unlist(authors)
    authors <- stringr::str_remove(authors, "^.+, \\{")
    authors <- stringr::str_remove(authors, "\\}")
    authors <- stringr::str_remove(authors, ".*,[:blank:]")
    authors <- stringr::str_remove(authors, "\\s.*")
    gender <- tryCatch({
      table(gender::gender(authors, method = "genderize")$gender)
    },
    message = "Rate limit for the `{gender}` R package has been reached due to the amount of download requests.
    Please wait a few hours and try again later."
    )
    if (!is.null(gender)) {
      paste0((1 - round(gender[2] / sum(gender), 2)) * 100,
             "% female authors") 
    }
  } else if (by == "publication") {
    # Percentage of papers written by at least one women
    for (i in seq_len(length(authors))) {
      for (j in seq_len(length(authors[[i]]))) {
        authors[[i]][[j]] <- stringr::str_remove(authors[[i]][[j]],
                                                 "^.+, \\{")
        authors[[i]][[j]] <- stringr::str_remove(authors[[i]][[j]],
                                                 "\\}")
        authors[[i]][[j]] <- stringr::str_remove(authors[[i]][[j]],
                                                 ".*,[:blank:]")
      }
    }
    gender <- tryCatch({
      sapply(authors, function(x)
        any(gender::gender(x, method = "genderize")$gender == "female"))
      },
      message = "Rate limit for the `{gender}` R package has been reached due to the amount of download requests.
      Please wait a few hours and try again later."
      )
    if (!is.null(gender)) {
      paste0(round(sum(gender) / length(gender), 2) * 100,
             "% female authors") 
    }
  }
}

#' @rdname bibstats
#' @export
mean_year <- function(bib_file, rmd_file) {
  if (missing(bib_file)) bib_file <- find_bib()
  if (missing(rmd_file)) rmd_file <- rstudioapi::getSourceEditorContext()$path
  bib <- suppressMessages(bib2df::bib2df(bib_file))
  if (!missing(rmd_file)) {
    used <- get_used_bib(bib_file, rmd_file)
    bib <- dplyr::filter(bib, .data$BIBTEXKEY %in% used)
  }
  years <- as.numeric(bib$YEAR)
  paste0("Average date of publication: ",
               round(mean(years, na.rm = TRUE)))
}

#' @rdname bibstats
#' @export
mean_pages <- function(bib_file, rmd_file) {
  if (missing(bib_file)) bib_file <- find_bib()
  if (missing(rmd_file)) rmd_file <- rstudioapi::getSourceEditorContext()$path
  bib <- suppressMessages(bib2df::bib2df(bib_file))
  if (!missing(rmd_file)) {
    used <- get_used_bib(bib_file, rmd_file)
    bib <- dplyr::filter(bib, .data$BIBTEXKEY %in% used)
  }
  pages <- bib$PAGES
  pages <- na.omit(pages)
  pages <- stringr::str_split(pages, "--")
  pages <- lapply(pages, function(x) {
    if (length(x) == 2) as.numeric(x[[2]]) - as.numeric(x[[1]])
    else as.numeric(x)
  })
  pages <- unlist(pages)
  paste0("Average number of pages: ", round(mean(pages)))
}

#' @rdname bibstats
#' @importFrom stats na.omit
#' @importFrom stringr str_split str_detect
#' @importFrom usethis ui_info
#' @importFrom fs path_dir
#' @export
total_pages <- function(bib_file, rmd_file) {
  if (missing(bib_file)) bib_file <- find_bib()
  bib <- suppressMessages(bib2df::bib2df(bib_file))
  if (!missing(rmd_file)) {
    used <- get_used_bib(bib_file, rmd_file)
    bib <- dplyr::filter(bib, .data$BIBTEXKEY %in% used)
  }
  pages <- bib$PAGES
  pages <- stats::na.omit(pages)
  pages <- stringr::str_split(pages, "--")
  pages <- lapply(pages, function(x) {
    if (length(x) == 2) as.numeric(x[[2]]) - as.numeric(x[[1]])
    else as.numeric(x)
  })
  pages <- unlist(pages)
  paste0("Total number of pages: ", round(sum(pages)))
}

find_bib <- function() {
  path <- rstudioapi::getSourceEditorContext()$path
  dir <- fs::path_dir(path)
  files <- list.files(dir)
  if (length(files[stringr::str_detect(files, ".bib")][[1]]) < 1)
    stop("No bibliography found for current document. Please specify one.")
  bib <- files[stringr::str_detect(files, ".bib")][[1]]
  bib_file <- paste0(dir, "/", bib)
  usethis::ui_info("Found .bib file `{bib}`")
  bib_file
}

test_that("Bibstats works properly", {
  testthat::skip_on_cran()
  rmarkdown::draft(file = "test", template = "syllabus",
                   package = "iheiddown", create_dir = TRUE, edit = FALSE)
  expect_equal(percent_female(bib_file = "test/references.bib",
                              rmd_file = "test/test.Rmd", by = "author"),
               "33% female authors")
  expect_equal(percent_female(bib_file = "test/references.bib",
                              rmd_file = "test/test.Rmd",
                              by = "publication"),
               "50% female authors")
  expect_equal(mean_year(bib_file = "test/references.bib",
                         rmd_file = "test/test.Rmd"),
               "Average date of publication: 1934")
  expect_equal(total_pages(bib_file = "test/references.bib",
                           rmd_file = "test/test.Rmd"),
               "Total number of pages: 7")
  expect_equal(mean_pages(bib_file = "test/references.bib",
                          rmd_file = "test/test.Rmd"),
               "Average number of pages: 7")
  unlink("test", recursive = TRUE)
})

# test_that("Bibfix works properly", {
#   rmarkdown::draft(file = "test", template = "syllabus",
#                    package = "iheiddown", create_dir = TRUE, edit = FALSE)
#   expect_equal(fix_bib(bib_file = "test/references.bib"),
#                "test/references.bib")
#   unlink("test", recursive = TRUE)
# })

#' A function for counting words in an Rmarkdown document.
#'
#' This function takes a path to a .Rmd file and returns a word count.
#' For best results each sentence should start on a new line.
#' Inline code chunks should also start on a new line.
#' 
#' @name countwords
#' @param file A path to a .Rmd file
#' @import dplyr
#' @importFrom rlang .data
#' @importFrom readr read_lines
#' @importFrom tibble as_tibble
#' @importFrom rstudioapi getSourceEditorContext
#' @importFrom tidytext unnest_tokens
#' @importFrom pdftools pdf_text
#' @return A scalar representing the number of words in the document.
#' @examples
#' rmarkdown::draft(file = "test", template = "html_vignette",
#' package = "rmarkdown", create_dir = TRUE, edit = FALSE)
#' iheiddown::count_words("test/test.Rmd")
#' unlink("test", recursive = TRUE)
#'
NULL

#' @rdname countwords
#' @export
count_words <- function(file) {
  # Get currently viewed panel in RStudio if file is not specified
  if (missing(file)) file <- rstudioapi::getSourceEditorContext()$path
  wc <- readr::read_lines(file) %>%
    tibble::as_tibble() %>%
    remove_front_matter() %>%
    remove_code_chunks() %>%
    remove_inline_code() %>%
    remove_html_comment() %>%
    tidytext::unnest_tokens(output = .data$words, input = .data$value) %>%
    nrow()
  return(wc)
}

#' @rdname countwords
#' @export
count_words2 <- function(file) {
  # Get currently viewed panel in RStudio if file is not specified
  if (missing(file)) {
    file <- rstudioapi::getSourceEditorContext()$path
    file <- stringr::str_replace(file, ".Rmd", ".pdf")
  } 
  
  pdf <- pdftools::pdf_text(file)
  wc <- sum(unlist(lapply(wc, function(x) length(x))))

  return(wc)
}


# Helper function for removing unwanted lines from count
# Checks is value is odd.
is_odd <- function(x, val) {
  x %% 2 == 1
}

# Helper function to remove front matter (lines starting with "---" and
# anything between)
remove_front_matter <- function(x) {
  mutate(x, is_code = cumsum(grepl("^---", value))) %>%
    group_by(is_code) %>%
    mutate(start_end = lag(is_code, 1)) %>%
    ungroup() %>%
    filter(!is_odd(is_code), !is.na(start_end)) %>%
    select(-is_code, -start_end)
}

# Helper function for removing knitr code chunks (lines starting with "```"
# and anything in between)
remove_code_chunks <- function(x) {
  mutate(x, is_code = cumsum(grepl("^```", value))) %>%
    group_by(is_code) %>%
    mutate(start_end = lag(is_code, 1)) %>%
    ungroup() %>%
    mutate(is_odd = is_odd(is_code)) %>%
    filter(is_odd != TRUE, !is.na(start_end)) %>%
    select(-is_code, -start_end, -is_odd)
}

# Helper function to remove inline code (lines starting with "`r")
remove_inline_code <- function(x) {
  filter(x, !grepl("`r", value))
}

# Helper function to remove HTML comments (lines starting with "<!--" and "-->")
remove_html_comment <- function(x) {
  mutate(x, start_comment = cumsum(grepl("^<!-- ", value)),
         end_comment = cumsum(grepl(" -->", value))) %>%
    group_by(start_comment, end_comment) %>%
    mutate(start_end = lag(start_comment, 1)) %>%
    ungroup() %>%
    mutate(remove = if_else(start_comment - end_comment == 1 |
                              is.na(start_end), 1, 0)) %>%
    filter(remove != TRUE) %>%
    select(-start_comment, -end_comment, -remove)
}

#' Manage iheiddown profile
#'
#' @description This RStudio Addin opens up the ~/_bookdown.yml file for
#' users to edit. If the file doesn't exists, it will create one.
#' @importFrom utils file.edit
#' @return Opens or creates a bookdown profile YAML file for the current thesis.
#' @export
bookdown_profile <- function() {
  profile_file <- getOption("_bookdown.yml", "~/_bookdown.yml")
  if (!file.exists(profile_file)) {
    file.copy(
      from = system.file("_bookdown.yml", package = "iheiddown"),
      to = profile_file
    )
  }
  file.edit(profile_file)
}

#' Previewing rmarkdown documents
#'
#' Use the \pkg{servr} package to continuously serve and reload
#' the Rmd document. Run \code{preview_start()} function while viewing the Rmd
#' panel of your presentation. To stop the server, run \code{preview_stop()}.
#' @name preview
#' @param file_path The input Rmd file path (if missing and in RStudio, the
#' current active document is used).
#' @param ... Additional arguments passed to
#' \code{rmarkdown::\link[rmarkdown]{render}()}.
#' @references xaringan
#' @importFrom xaringan inf_mr
#' @return Starts serving the current files to RStudio's Viewer pane.
#' @export
preview_start <- function(file_path, ...) {
  xaringan::inf_mr(moon = file_path, ...)
  message("Preview started")
}

#' @rdname preview
#' @param which An integer vector of the server IDs;
#' by default, IDs of all existing servers in the current R session obtained
#' from `daemon_list()`, i.e., all daemon servers will be stopped by default.
#' @importFrom servr daemon_stop daemon_list
#' @return Stops serving the current files to RStudio's Viewer pane.
#' @export
preview_stop <- function(which = NULL) {
  if (is.null(which)) which <- servr::daemon_list()
  servr::daemon_stop(which)
  message("Preview stopped")
}

test_that("Live preview with preview_stop() works", {
  expect_message(iheiddown::preview_stop("test_stop/test_stop.Rmd"),
                           "Preview stopped")
})
# # Hacky test since the function is not really testable.
# test_that("Live preview with preview_stop() works", {
#   expect_error(suppressWarnings(iheiddown::preview_start("test_stop/test_stop.Rmd")),
#                            paste0("The file '", getwd(),
#                                   "/test_stop/test_stop.Rmd' does not exist."))
# })

#' A ggplot2 theme for IHEID style plots. Adapted from Hrbrmstr's ipsum theme.
#' 
#' @importFrom ggplot2 theme margin element_text element_blank element_line
#' element_rect
#' @param base_family,base_size base font family and size
#' @param plot_title_family,plot_title_face,plot_title_size,plot_title_margin
#' plot title family, face, size and margi
#' @param subtitle_family,subtitle_face,subtitle_size
#' plot subtitle family, face and size
#' @param subtitle_margin plot subtitle margin bottom (single numeric value)
#' @param strip_text_family,strip_text_face,strip_text_size
#' facet label font family, face and size
#' @param caption_family,caption_face,caption_size,caption_margin
#' plot caption family, face, size and margin
#' @param axis_title_family,axis_title_face,axis_title_size
#' axis title font family, face and size
#' @param axis_title_just axis title font justification, one of `[blmcrt]`
#' @param plot_margin plot margin (specify with `ggplot2::margin()`)
#' @param grid_col,axis_col grid & axis colors; both default to `#cccccc`
#' @param grid panel grid (`TRUE`, `FALSE`, or a
#' combination of `X`, `x`, `Y`, `y`)
#' @param axis_text_size font size of axis text
#' @param axis add x or y axes? `TRUE`, `FALSE`, "`xy`"
#' @param ticks ticks if `TRUE` add ticks
#' @return Themes the current ggplot to current IHEID guidelines.
#' @examples
#' library(ggplot2)
#' library(dplyr)
#'
#' # seminal scatterplot
#' ggplot(mtcars, aes(mpg, wt)) +
#'   geom_point() +
#'   labs(x="Fuel efficiency (mpg)", y="Weight (tons)",
#'        title="Seminal ggplot2 scatterplot example",
#'        subtitle="A plot that is only useful for demonstration purposes",
#'        caption="Brought to you by the letter 'g'") +
#'   theme_iheid()
#'
#' # seminal bar chart
#' count(mpg, class) %>%
#'   ggplot(aes(class, n)) +
#'   geom_col() +
#'   geom_text(aes(label=n), nudge_y=3) +
#'   labs(x="Fuel efficiency (mpg)", y="Weight (tons)",
#'        title="Seminal ggplot2 bar chart example",
#'        subtitle="A plot that is only useful for demonstration purposes",
#'        caption="Brought to you by the letter 'g'") +
#'   theme_iheid(grid="Y") +
#'   theme(axis.text.y=element_blank())
#' @export
theme_iheid <- function(base_family="sans", base_size = 11.5,
                        plot_title_family=base_family, plot_title_size = 18,
                        plot_title_face="bold", plot_title_margin = 10,
                        subtitle_family=base_family, subtitle_size = 12,
                        subtitle_face = "plain", subtitle_margin = 15,
                        strip_text_family = base_family, strip_text_size = 12,
                        strip_text_face = "plain",
                        caption_family = base_family, caption_size = 9,
                        caption_face = "italic",
                        caption_margin = 10,
                        axis_text_size = base_size,
                        axis_title_family = subtitle_family,
                        axis_title_size = 9,
                        axis_title_face = "plain",
                        axis_title_just = "rt",
                        plot_margin = margin(30, 30, 30, 30),
                        grid_col = "grey85",
                        grid = TRUE,
                        axis_col = iheid_palette("IHEID")["IHEIDBlack"],
                        axis = FALSE,
                        ticks = FALSE) {
  # ret is set as the base theme of ggplot
    ret <- ggplot2::theme_minimal(base_family = base_family,
                                  base_size = base_size)
    ret <- ret + theme(legend.background = element_blank())
    ret <- ret + theme(legend.key = element_blank())
    # Set grid
    if (inherits(grid, "character") | grid == TRUE) {
      ret <- ret +
        theme(panel.grid = element_line(color = grid_col, linewidth = 0.2))
      ret <- ret +
        theme(panel.grid.major = element_line(color = grid_col,
                                              linewidth = 0.2))
      ret <- ret +
        theme(panel.grid.minor = element_line(color = grid_col,
                                              linewidth = 0.15))
      if (inherits(grid, "character")) {
        if (regexpr("X", grid)[1] < 0) ret <- ret +
            theme(panel.grid.major.x = element_blank())
        if (regexpr("Y", grid)[1] < 0) ret <- ret +
            theme(panel.grid.major.y = element_blank())
        if (regexpr("x", grid)[1] < 0) ret <- ret +
            theme(panel.grid.minor.x = element_blank())
        if (regexpr("y", grid)[1] < 0) ret <- ret +
            theme(panel.grid.minor.y = element_blank())
      }
    } else {
      ret <- ret +
        theme(panel.grid = element_blank())
    }
    # Set axis
    if (inherits(axis, "character") | axis == TRUE) {
      ret <- ret +
        theme(axis.line = element_line(color =
                                         iheid_palette("IHEID")["IHEIDBlack"],
                                      linewidth = 0.15))
      if (inherits(axis, "character")) {
        axis <- tolower(axis)
        if (regexpr("x", axis)[1] < 0) {
          ret <- ret +
            theme(axis.line.x = element_blank())
        } else {
          ret <- ret +
            theme(axis.line.x = element_line(color = axis_col,
                                             linewidth = 0.15))
        }
        if (regexpr("y", axis)[1] < 0) {
          ret <- ret +
            theme(axis.line.y = element_blank())
        } else {
          ret <- ret +
            theme(axis.line.y = element_line(color = axis_col,
                                             linewidth = 0.15))
        }
      } else {
        ret <- ret +
          theme(axis.line.x = element_line(color = axis_col, linewidth = 0.15))
        ret <- ret +
          theme(axis.line.y = element_line(color = axis_col, linewidth = 0.15))
      }
    } else {
      ret <- ret +
        theme(axis.line = element_blank())
    }
    # Set Ticks
    if (!ticks) {
      ret <- ret + theme(axis.ticks = element_blank())
      ret <- ret + theme(axis.ticks.x = element_blank())
      ret <- ret + theme(axis.ticks.y = element_blank())
    } else {
      ret <- ret + theme(axis.ticks = element_line(linewidth = 0.15))
      ret <- ret + theme(axis.ticks.x = element_line(linewidth = 0.15))
      ret <- ret + theme(axis.ticks.y = element_line(linewidth = 0.15))
      ret <- ret + theme(axis.ticks.length = grid::unit(5, "pt"))
    }
    # Set the position of axis title
    xj <- switch(tolower(substr(axis_title_just, 1, 1)),
                 b = 0,
                 l = 0,
                 m = 0.5,
                 c = 0.5,
                 r = 1,
                 t = 1)
    yj <- switch(tolower(substr(axis_title_just, 2, 2)),
                 b = 0,
                 l = 0,
                 m = 0.5,
                 c = 0.5,
                 r = 1,
                 t = 1)
    # Other axis elements
    ret <- ret + theme(axis.text.x = element_text(size = axis_text_size,
                                                margin = margin(t = 0),
                                                colour = "#5c666f",
                                                family = "sans"))
    ret <- ret + theme(axis.text.y = element_text(size = axis_text_size,
                                                margin = margin(r = 0),
                                                colour = "#5c666f",
                                                family = "sans"))
    ret <- ret + theme(axis.title = element_text(size = axis_title_size,
                                                 family = axis_title_family))
    ret <- ret + theme(axis.title.x = element_text(hjust = xj,
                                                   size = axis_title_size,
                                                 family = axis_title_family,
                                                 face = axis_title_face))
    ret <- ret + theme(axis.title.y = element_text(hjust = yj,
                                                   size = axis_title_size,
                                                   family = axis_title_family,
                                                   face = axis_title_face))
    ret <- ret +
      theme(axis.title.y.right = element_text(hjust = yj,
                                              size = axis_title_size,
                                              angle = 90,
                                              family = axis_title_family,
                                              face = axis_title_face))
    # Facet elements
    ret <- ret + theme(strip.text = element_text(hjust = 0,
                                                 size = strip_text_size,
                                                 face = strip_text_face,
                                                 family = strip_text_family))
    # Spacing between panels
    ret <- ret + theme(panel.spacing = grid::unit(2, "lines"))
    # Plot Title
    ret <- ret +
      theme(plot.title = element_text(hjust = 0,
                                      size = plot_title_size,
                                      margin = margin(b = plot_title_margin),
                                      family = plot_title_family,
                                      face = plot_title_face,
                                      color =
                                        iheid_palette("IHEID")["IHEIDRed"]))
    ret <- ret +
      theme(plot.subtitle = 
              element_text(hjust = 0,
                           size = subtitle_size,
                           family = subtitle_family,
                           face = subtitle_face,
                           color = iheid_palette("IHEID")["IHEIDBlack"]))
    ret <- ret +
      theme(plot.caption =
              element_text(hjust = 1,
                           size = caption_size,
                           margin = margin(t = caption_margin),
                           family = caption_family,
                           face = caption_face,
                           color = iheid_palette("IHEID")["IHEIDGrey"]))
    ret <- ret + theme(plot.margin = plot_margin)
    ret
}

test_that("theme_iheid() axes are correct", {
  p <- ggplot2::ggplot(iris, ggplot2::aes(x = Sepal.Length, y = Sepal.Width)) +
    ggplot2::geom_point() +
    iheiddown::theme_iheid()
  expect_identical(p$theme$axis.text.x$family, "sans")
  expect_identical(p$theme$axis.text.x$family, "sans")
  expect_identical(unname(p$theme$axis.text.x$colour), "#5c666f")
  expect_identical(unname(p$theme$axis.text.y$colour), "#5c666f")
  expect_identical(p$theme$axis.text.x$size, 11.5)
  expect_identical(p$theme$axis.text.y$size, 11.5)
})

test_that("theme_iheid() title is correct", {
  p <- ggplot2::ggplot(iris, ggplot2::aes(x = Sepal.Length, y = Sepal.Width)) +
    ggplot2::ggtitle("Test") + ggplot2::geom_point() +
    iheiddown::theme_iheid()
  expect_identical(p$theme$plot.title$family, "sans")
  expect_identical(unname(p$theme$plot.title$colour), "#E20020")
  expect_identical(p$theme$plot.title$size, 18)
})

test_that("theme_iheid() grid is correct", {
  p <- ggplot2::ggplot(iris, ggplot2::aes(x = Sepal.Length, y = Sepal.Width)) +
    ggplot2::ggtitle("Test") + ggplot2::geom_point() +
    iheiddown::theme_iheid()
  expect_identical(p[["theme"]][["panel.grid"]][["colour"]],
                   "grey85")
  expect_identical(p[["theme"]][["panel.grid"]][["linewidth"]], 0.2)
})

test_that("theme_iheid() caption style is correct", {
  p <- ggplot2::ggplot(iris, ggplot2::aes(x = Sepal.Length, y = Sepal.Width)) +
    ggplot2::ggtitle("Test") + ggplot2::geom_point() +
    iheiddown::theme_iheid()
  expect_identical(p[["theme"]][["plot.caption"]][["colour"]][["IHEIDGrey"]],
                   "#6f7072")
  expect_identical(p[["theme"]][["plot.caption"]][["family"]], "sans")
  expect_identical(p[["theme"]][["plot.caption"]][["face"]], "italic")
  expect_identical(p[["theme"]][["plot.caption"]][["size"]], 9)
})

test_that("theme_iheid() strip style is correct", {
  p <- ggplot2::ggplot(iris, ggplot2::aes(x = Sepal.Length, y = Sepal.Width)) +
    ggplot2::ggtitle("Test") + ggplot2::geom_point() +
    iheiddown::theme_iheid()
  expect_identical(p[["theme"]][["strip.text"]][["family"]], "sans")
  expect_identical(p[["theme"]][["strip.text"]][["size"]], 12)
  expect_identical(p[["theme"]][["strip.text"]][["face"]], "plain")
})

test_that("theme_iheid() subtitle style is correct", {
  p <- ggplot2::ggplot(iris, ggplot2::aes(x = Sepal.Length, y = Sepal.Width)) +
    ggplot2::ggtitle("Test") + ggplot2::geom_point() +
    iheiddown::theme_iheid()
  expect_identical(p[["theme"]][["plot.subtitle"]][["family"]], "sans")
  expect_identical(p[["theme"]][["plot.subtitle"]][["size"]], 12)
  expect_identical(p[["theme"]][["plot.subtitle"]][["face"]], "plain")
  expect_identical(p[["theme"]][["plot.subtitle"]][["colour"]][["IHEIDBlack"]],
                   "#5c666f")
})

test_that("theme_iheid() caption style is correct", {
  p <- ggplot2::ggplot(iris, ggplot2::aes(x = Sepal.Length, y = Sepal.Width)) +
    ggplot2::ggtitle("Test") + ggplot2::geom_point() +
    iheiddown::theme_iheid()
  expect_identical(p[["theme"]][["plot.caption"]][["colour"]][["IHEIDGrey"]],
                   "#6f7072")
  expect_identical(p[["theme"]][["plot.caption"]][["family"]], "sans")
  expect_identical(p[["theme"]][["plot.caption"]][["face"]], "italic")
  expect_identical(p[["theme"]][["plot.caption"]][["size"]], 9)
})

#' Creates an R Markdown PDF Problem Set document
#'
#' This is a function called in output in the YAML of the driver Rmd file
#' to specify using the IHEID Problem Set LaTeX template file.
#'
#' @export
#'
#' @param ... Instructions passed to the function from a correctly specified
#' .Rmd document
#' @param input The name of the .Rmd file to serve as input.
#' @importFrom rmarkdown pdf_document
#' @return A modified \code{pdf_document} based on the IHEID Problem Set LaTeX
#'   template, automatically named by course and date.
#' @examples
#' \dontrun{
#' output:
#'   iheiddown::problemset_pdf:
#'     input: "Untitled.Rmd"
#'     # Replace with whatever the name of this file is, e.g. "MINT001.Rmd"
#' }
problemset_pdf <- function(input, ...) {
  code <- readLines(input)
  code <- code[grepl("^code:", code)]
  code <- strsplit(code, " ")[[1]][2]
  rmarkdown::render(input,
                    output_file = paste0(code, "_ProblemSet_", Sys.Date()),
                    ...,
                    output_format = rmarkdown::pdf_document(
                      latex_engine = "xelatex",
                      template = system.file("rmarkdown",
                                             "templates",
                                             "problemset_pdf",
                                             "resources",
                                             "template.tex",
                                             package = "iheiddown")))
}

#' Complete list of palettes
#'
#' Use \code{\link{iheid_palette}} to construct palettes of desired length.
#'
#' @export
iheid_palettes <- list("IHEID" = c("IHEIDRed" = "#E20020",
                                   "IHEIDBlack" = "#5c666f",
                                   "IHEIDGrey" = "#6f7072"),
                       "Centres" = c("AHCD" = "#622550",
                                     "CFFD" = "#0094D8",
                                     "CIES" = "#268D2B",
                                     "CTEI" = "#008F92",
                                     "CGEN" = "#820C2B",
                                     "CCDP" = "#3E2682",
                                     "GLGC" = "#006564",
                                     "GLHC" = "#A8086E",
                                     "GLMC" = "#006EAA"),
                       "SDGs" = c("NoPoverty" = "#e5243b",
                                  "ZeroHunger" = "#DDA63A",
                                  "GoodHealth" = "#4C9F38",
                                  "QualityEducation" = "#C5192D",
                                  "GenderEquality" = "#FF3A21",
                                  "CleanWater" = "#26BDE2",
                                  "CleanEnergy" = "#FCC30B",
                                  "EconomicGrowth" = "#A21942",
                                  "Innovation" = "#FD6925",
                                  "ReducedInequalities" = "#DD1367",
                                  "SustainableCities" = "#FD9D24",
                                  "ResponsibleConsumption" = "#BF8B2E",
                                  "ClimateAction" = "#3F7E44",
                                  "BelowWater" = "#0A97D9",
                                  "OnLand" = "#56C02B",
                                  "StrongInstitutions" = "#00689D",
                                  "GoalPartnerships" = "#19486A"))

#' An IHEID palette generator
#'
#' These are a few color palettes useful for members of the  Geneva Graduate Institute.
#' This function calls one of three official palettes in
#' \code{\link{iheid_palette}}: for the Institute, for the Centres, and for the
#' SDGs.
#'
#' @param n Number of colors desired. If omitted, uses all colours.
#' @param name Name of desired palette. Current choices are:
#'   \code{IHEID}, \code{Centres}, and \code{SDGs}.
#' @param type Either "continuous" or "discrete". Use continuous if you want
#'   to automatically interpolate between colours.
#' @importFrom graphics rect par image text
#' @return A vector of colours.
#' @source Adapted from
#' \url{https://github.com/karthik/wesanderson/blob/master/R/colors.R}
#' @export
#' @keywords colors
#' @examples
#' iheid_palette("IHEID")
#' iheid_palette("Centres")
#' iheid_palette("SDGs")
#'
#' # If you need more colours than normally found in a palette, you
#' # can use a continuous palette to interpolate between existing
#' # colours
#' pal <- iheid_palette(21, name = "Centres", type = "continuous")
#' image(volcano, col = pal)
iheid_palette <- function(name, n, type = c("discrete", "continuous")) {
  type <- match.arg(type)
  pal <- iheid_palettes[[name]]
  if (is.null(pal))
    stop("Palette not found.")
  if (missing(n)) {
    n <- length(pal)
  }
  if (type == "discrete" && n > length(pal)) {
    stop("Number of requested colors greater than what palette can offer")
  }
  out <- switch(type,
                continuous = grDevices::colorRampPalette(pal)(n),
                discrete = pal[1:n]
  )
  structure(out, class = "palette", name = name)
}

#' @export
#' @importFrom graphics rect par image text
#' @importFrom grDevices rgb
print.palette <- function(x, ...) {
  n <- length(x)
  old <- par(mar = c(0.5, 0.5, 0.5, 0.5))
  on.exit(par(old))
  image(1:n, 1, as.matrix(1:n), col = x,
        ylab = "", xaxt = "n", yaxt = "n", bty = "n")
  rect(0, 0.9, n + 1, 1.1, col = rgb(1, 1, 1, 0.8), border = NA)
  text((n + 1) / 2, 1, labels = attr(x, "name"), cex = 1, family = "serif")
}

test_that("palettes work", {
  expect_equal(unname(iheid_palette("IHEID")[1]), "#E20020")
  expect_equal(unname(iheid_palette("IHEID")[2]), "#5c666f")
  expect_equal(unname(iheid_palette("IHEID")[3]), "#6f7072")
  expect_equal(unname(iheid_palette("Centres")[3]), "#268D2B")
  expect_equal(unname(iheid_palette("SDGs")[3]), "#4C9F38")
})

#' Creates an R Markdown PDF Thesis document
#'
#' This is a function called in output in the YAML of the driver Rmd file
#' to specify using the IHEID Thesis LaTeX template file.
#' @param input Rmd input file that will be processed by the function.
#' @param ... Instructions passed to the function from a correctly specified
#' .Rmd document
#' @return A modified \code{pdf_document} based on the IHEID Thesis LaTeX
#'   template
#' @examples
#' \dontrun{
#' knit: iheiddown::thesis_pdf
#' }
#' @importFrom bookdown render_book pdf_book
#' @export
thesis_pdf <- function(input = ".", ...) {
  options(bookdown.render.file_scope = FALSE)
  author <- readLines(input)
  author <- author[grepl("^lastnames:", author)]
  author <- strsplit(author, " ")[[1]][2]
  bookdown::render_book(...,
                        output_file =
                          paste0("Thesis_",
                                 author,
                                 "_",
                                 Sys.Date()),
                        output_format = bookdown::pdf_book(
                          latex_engine = "xelatex",
                          template = system.file("rmarkdown",
                                                 "templates",
                                                 "thesis_pdf",
                                                 "resources",
                                                 "template.tex",
                                                 package = "iheiddown"),
                          citation_package = "biblatex"))
  file.remove(c(list.files(pattern = ".*.maf", recursive = TRUE),
                list.files(pattern = ".*.mtc", recursive = TRUE)))
}

#' Creates an R Markdown PDF Thesis chapter
#'
#' This function can be used in the header of each constituent chapter of an
#' IHEID thesis to output a draft version of the chapter for proofreading or
#' sending to your supervisor.
#' @param input Rmd input file that will be processed by the function.
#' @param ... Instructions passed to the function from a correctly specified
#' .Rmd document
#' @importFrom bookdown preview_chapter
#' @importFrom rmarkdown pdf_document
#' @import crayon
#' @return A modified \code{pdf_document} based on the IHEID Thesis LaTeX
#'   template
#' @examples
#' \dontrun{
#' knit: iheiddown::chapter_pdf
#' }
#' @export
chapter_pdf <- function(input, ...) {
  # Extract metadata to check whether to knit in context or not.
  in_context <- readLines(input)
  in_context <- in_context[grepl("^in_context:", in_context)]
  in_context <- strsplit(in_context, " ")[[1]][2]
  if (in_context) {
    # Extract metadata to name output file without running into annoying
    # bookdown error
    author <- readLines(input)
    author <- author[grepl("^author:", author)]
    author <- strsplit(author, " ")[[1]][2]
    chapter <- readLines(input)
    chapter <- chapter[grepl("^chapter:", chapter)]
    chapter <- strsplit(chapter, " ")[[1]][2]
    message("In-context rendering")
    #Render chapter
    bookdown::preview_chapter(input = input, ...,
                              output_file =
                                paste0("versions/",
                                       author, "_",
                                       "Chapter_",
                                       chapter, "_",
                                       Sys.Date()),
                              output_format =
                                rmarkdown::pdf_document(
                                  latex_engine = "xelatex",
                                  template =
                                    system.file("rmarkdown",
                                                "templates",
                                                "chapter_pdf",
                                                "resources",
                                                "template.tex",
                                                package = "iheiddown")))
    file.remove(c(list.files(pattern = ".*.maf", recursive = TRUE),
                  list.files(pattern = ".*.mtc", recursive = TRUE)))
  } else {
    # Extract metadata to name output file without running into annoying
    # bookdown error
    author <- readLines(input)
    author <- author[grepl("^author:", author)]
    author <- strsplit(author, " ")[[1]][2]
    chapter <- readLines(input)
    chapter <- chapter[grepl("^chapter:", chapter)]
    chapter <- strsplit(chapter, " ")[[1]][2]
    message("Out of context rendering")
    #Render chapter
    rmarkdown::render(input, ...,
                      output_file = paste0("versions/",
                                           author, "_",
                                           "Chapter_",
                                           chapter,
                                           "_",
                                           Sys.Date()),
                      output_format =
                        rmarkdown::pdf_document(latex_engine = "xelatex",
                                                template =
                                                  system.file("rmarkdown",
                                                              "templates",
                                                              "chapter_pdf",
                                                              "resources",
                                                              "template.tex",
                                                              package =
                                                                "iheiddown")))
  }
}

# Testing that the thesis rendering works
# 
# Still need to install miktex or some stuff on all runners before running these
# tests
# test_that("thesis_pdf() works", {
#   # Setup
#   rmarkdown::draft(file = paste0(test_path(), "/00-Example"), template = "thesis",
#                    package = "iheiddown", create_dir = TRUE, edit = FALSE)
#   setwd(paste0(test_path(), "/00-Example"))
#   file.rename("00-Example.Rmd", "index.Rmd")
#   iheiddown::thesis_pdf("index.Rmd")
#   iheiddown::chapter_pdf("01-introduction.Rmd")
#   # Test
#   expect_true(file.exists(paste0("versions/Thesis_Name_", Sys.Date(), ".pdf")))
#   expect_true(file.exists(paste0("versions/Author_Chapter_1_", Sys.Date(), ".pdf")))
#   # Clean
#   setwd("../../..")
#   unlink(paste0(test_path(), "/00-Example"), recursive = TRUE)
# })

---
####################
## Metadata       ##
####################
doctitle: |
  `iheiddown`: \
  A Thesis Template \
  For the Geneva Graduate Institute \
  in R Markdown
firstnames: Author
lastnames: Name
thesisno: 12345
phd: true # Or: false for Masters
department: Your Department
degreedate: June 2020
supervisor: Gandalf the Grey
secondreader: Galadriel
examiner: Aragorn II Elessar # only required if PhD; otherwise delete or comment out
# This is the YAML (YAML Ain't Markup Language) header that includes 
# metadata used to produce the document. 
# Be careful with spacing in this header!
# Two spaces at the start of the line create indentation,
# which embeds the parameter in a hierarchy.

####################
## Front Matter   ##
####################
dedication: For you #If you'd prefer to not include a Dedication, for example, simply delete the section entirely, or silence them (add # before each line). 
resume: | # otherwise known as the abstract
  `r paste(readLines("front-matter/_abstract.Rmd"), collapse = '\n  ')`
acknowledgements: |
  `r paste(readLines("front-matter/_acknowledgements.Rmd"), collapse = '\n  ')`
abbreviations: "front-matter/abbreviations" # path to .tex file with abbreviations
toc-depth: 2 # depth of heading to include in table of contents
lof: true # list of figures in front matter?
lot: true # list of tables in front matter?
mini-toc: false  # mini-table of contents at start of each chapter? (this just prepares it; you must also add \minitoc after the chapter titles)
mini-lot: false  # mini-list of tables by start of each chapter?
mini-lof: false  # mini-list of figures by start of each chapter?

####################
## Bibliography   ##
####################
bibliography: bib/references.bib #Set your bibliography file here.
bibliography-heading-in-pdf: References
bib-style: authoryear # See https://www.overleaf.com/learn/latex/biblatex_citation_styles for a list of the commonly used built-in citations styles of biblatex.
bib-sorting: nyt #See https://www.overleaf.com/learn/latex/Articles/Getting_started_with_BibLaTeX for different bibliography sorting options.
citeall: true #Set this to true if you want all elements in your .bib file to appear in your bibliography (i.e. all R-packages you used).

#####################
## PDF Formatting  ##
#####################
draft: false # add DRAFT mark in the footer and line numbering?
page-layout: oneside #'oneside' for PDF output (equal margins), 
# or 'twoside' for two-sided binding (mirror margins and blank pages) 
hidelinks: false #if false, the PDF output highlights clickable links with a colored border 
# you will probably want to set this to true for PDF version you wish to physically print
knit: iheiddown::thesis_pdf
#####################
## Output Options  ##
#####################
output: iheiddown::thesis_pdf
link-citations: true
documentclass: book
---

# Preface {.unnumbered}

<!-- 
The {.unnumbered} option here means that the introduction will be 
"Chapter 0." You can also use {-} for no numbers on chapters.
-->

<!-- This chunk creates automatically a .bib file to cite the loaded packages in the bibliography. Do not forget to set "citeall" to true in the bibliography section of the YAML header if you want all packages to be cited even if you did not mention them in the body of the text.-->

```{r, include=FALSE}
knitr::write_bib(c(.packages(), "bookdown"), "bib/packages.bib")
```


Welcome to the *RMarkdown* template for writing masters theses or PhD dissertations 
at the Geneva Graduate Institute. 
This sample content is based on the [IHEID  LaTeX dissertation template](https://github.com/iheid-library/iheidmytex) and the R `bookdown` package.

But hopefully it will provide a nicer interface for those that have never used \TeX\ or \LaTeX\ before.

Using _R Markdown_ will also allow you to easily keep track of your analyses in **R** chunks of code, 
with the resulting plots and output included as well.  
The hope is this _R Markdown_ template gets you in the habit of doing reproducible research, 
which benefits you long-term as a researcher, 
but also will greatly help anyone that is trying to reproduce or build onto your results down the road.

Hopefully, you won't have much of a learning period to go through and you will reap the benefits of a nicely formatted thesis.  
The use of \LaTeX\ in combination with _Markdown_ is more consistent than the output of a word processor, 
much less prone to corruption or crashing, 
and the resulting file is smaller than a Word file. 
While you may have never had problems using Word in the past, 
your thesis is likely going to be about twice as large and complex as anything you've written before, taxing Word's capabilities.  
After working with _Markdown_ and **R** together for a few weeks, 
we are confident this will be your reporting style of choice going forward.

## Why use it? {-}

_RMarkdown_ creates a simple and straightforward way to interface with the beauty of \LaTeX\.  
Packages have been written in **R** to work directly with \LaTeX\ to produce nicely formatting tables and paragraphs. 
In addition to creating a user friendly interface to \LaTeX\, _RMarkdown_ also allows you to read in your data, to analyze it and to visualize it using **R** functions, and also to provide the documentation and commentary on the results of your project.  
Further, it allows for **R** results to be passed inline to the commentary of your results.  
You'll see more on this later.  

## Who should use it? {-}

Anyone who needs to analyses data, include lots of tables or figures, complex cross-references, mathematical equations,
or just cares about the final appearance of their document should use *RMarkdown*.
Therefore, while this template should be of particular interest to those planning to use **R** for their dissertations,
the user-friendly nature of writing _Markdown_ 
coupled with the extraordinary flexibility of \LaTeX\
(and the power of **R**)
should make *useful for everyone writing theses or dissertations at the Geneva Graduate Institute*.

---
title: "Writing your problem sets"
author: "Bernhard Bieri"
date: "`r Sys.Date()`"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{Writing your problem sets}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r global.options, include = FALSE}
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>",
  fig.align = 'center',
  fig.width = 6,
  fig.height = 4
)
```

```{r setup, include=FALSE}
pkgs <- c("iheiddown", "magrittr", "ggplot2")
lapply(pkgs, library, character.only = TRUE)
```

While `{iheiddown}`'s main aim is to assist students in writing their thesis, it
can also be used for shorter projects such as problem sets. This short article
will walk you through the process of using the problem set template.

## Installation

The installation process is the same than for the thesis template. You'll need
the following software:

1. Install [R](https://cran.r-project.org) and [R-Studio](https://posit.co/)
2. Install a LATEX distribution:
    - [For MacOS](https://www.tug.org/mactex/)
    - [For Windows](https://miktex.org/)
    - [For Linux](https://www.tug.org/texlive/)
3. Install `{iheiddown}` by typing the following command
`install.packages("iheiddown") ` in the R-Studio console. 

Note: typing `remotes::install_github("jhollway/iheiddown")` will provide you
with the latest version from GitHub.

## Create your first problem set 

Creating your first problem set is easy! Before we begin, we have to create a
new R project by clicking on the file tab in the
top of the RStudio window and following the instructions of the prompt that
appears. Now that we have created an R project for our presentation, we can open
a new R-Markdown file. To do this click on the "plus file" logo in the top left
corner and then on "R-Markdown".

```{r, echo = FALSE, out.width="80%", fig.cap="Step 1: Open a project"}
  knitr::include_graphics("images/problemset/0-Open_Project.png", dpi = 144)
```

After you have done this, a little pop-up helper will appear. The first thing we
will do is to select the `{iheiddown}` template for our presentation. To do so,
click on the "From Template" option on the left and select the
"Problem Set {iheiddown}" template. Now give your file a name and click
on "OK".

```{r, echo = FALSE, out.width="80%", fig.cap="Step 2: Select a template"}
  knitr::include_graphics("images/problemset/1-Create_PS.png", dpi = 144)
```

Congrats! You just created your first problem set! We can actually already
render our problem set. This is done by simply clicking the "knit button"
while viewing the `MyProblemSet.Rmd` pane. Et voilà! You have now successfully
generated your first problem set with R.

Take a moment to read through the generated problem set to get acquainted
with the `{R-markdown}` syntax and to get a feel of the possibilities of the
`{iheiddown}` theme.

## Edit your problem set

This section will focus on giving you an overview of the workflow of writing
your problem sets in R with`{iheiddown}`.

### Set YAML options

The general options are set in the YAML header. You can define the metadata such
as the name of the authors, the course code *(required for the file name)*, and
the course name.

You can also set bibliographic options such as the `.bib` file you want to draw
your references from (`references.bib` by default) and the style of the
bibliographic entries by altering the `.csl` file. Note that packages that were
used in the code chunks of your problem set have their citation information
automatically written to a second `.bib` file called `packages.bib`. That way
you easily give appropriate credit to the work of the creators of the packages
you use.

That's it! You're now all set to focus on the content of your problem sets.
Again, please take a moment to read through the problem set template once it
is generated as it serves as much as a tutorial than this vignette.

### Understanding the appendix section

You might have spotted a somewhat unusual code chunk at the end of the file in
the appendix section. 

````markdown
`r ''````{r ref.label=knitr::all_labels(), echo=TRUE, eval=FALSE}
````

This special code chunk displays all the code you ran neatly at the end of your
analysis. This will help you keep your problem sets clean while still providing
your reader with a high level of transparency on how you manipulated your data
and created your output.

---
title: Introduction
author: Author
chapter: 1
in_context: True
knit: iheiddown::chapter_pdf
abstract: |
  In this chapter, I'll introduce how to write basic text using markdown.
  It is super simple, as you will see. You just write normal text,
  but then indicate where you want certain formatting with some very basic 'markup'.
output: iheiddown::chapter_pdf
---

\setcounter{chapter}{0}
# Introduction {#intro}

Here is a brief introduction into using *RMarkdown*.
_Markdown_ is a simple formatting syntax for authoring HTML, PDF, and MS Word documents.
_RMarkdown_ provides the flexibility of _Markdown_ with the implementation of **R** input and output.
For more details on using _RMarkdown_ see <https://rmarkdown.rstudio.com>.

## Commenting

<!-- 
If you'd like to include a comment that won't be produced in your resulting file 
enclose it in a block like this.
-->

<!-- If it's just a single line, you can wrap it like this. -->

As you can see in the final PDF, the above comments are not printed.
This can be hugely helpful for keeping notes for yourself
right where you need them.
I'll be using them to add some notes for you about the functionality in this package.

<!--
The {#intro} text after the chapter declaration will allow us to link throughout the document back to the beginning of Chapter 1.  
These labels will automatically be generated (if not specified) by changing the spaces to hyphens and capital letters to lowercase.  
Look for the reference to this label at the beginning of Chapter 2.
-->

## Line breaks, paragraphs, and spacing

Generally, it's useful to write each sentence (or part of a new sentence) on a new line.
This aids in readability---for you writing, but also for your readers, who will appreciate short, succinct prose.
Any text written in the line immediately following will be included in the same paragraph.
You do not need to add a space after finishing a line.
This will be added automatically.

If you want to start a new paragraph, all you need to do is hit enter/return twice before continuing writing.
The empty line signals that the paragraph is over, and we should start a new one.

Be careful with your spacing in _Markdown_ documents though.
While whitespace largely is ignored, it does at times give _Markdown_ signals as to how to proceed.
For example, at the end of this line, I'm going to add several white spaces.   
And then I'm going to continue.  
As you will see in the final PDF, while the paragraph structure is maintained,
the standard text justification is broken.

As a habit, try to keep everything left aligned whenever possible, especially as you type a new paragraph.
In other words, there is no need to indent basic text in the Rmd document 
(in fact, it might cause your text to do funny things if you do).

\vfill

If for some reason you need some extra space between paragraphs,
you can use `\vfill`.
You can force a new page with `\newpage`.

\newpage

## Quotation

Normal in-text quotations are simple enough.
Just "enclose the quotation in speech marks".
\LaTeX\ will do the hard work of parsing out what is the start and end of the quote.

If you wish to include longer quotations as a block quote,
just start a new paragraph with a > symbol preceding the first line.

> This signals that the quotation should be indented from both sides.
I can add sentences to the paragraph,
and to conclude the block quotation...

I just start another paragraph.
If you would like fancier block quotes,
just raise this as an issue [on GitHub](https://github.com/iheid-library/iheiddown).

## Lists

It's easy to create a list.
It can be unordered like

* Item 1
* Item 2

or it can be ordered like

1. Item 1
4. Item 2

Note that I intentionally mislabeled Item 2 as number 4.  
_Markdown_ automatically figures this out!  
You can put any numbers in the list and it will create the list.  
Check it out below.

To create a sublist, just indent the values a bit (at least four spaces or a tab).  
(Here's one case where indentation is key!)

1. Item 1
1. Item 2
1. Item 3
    - Item 3a
    - Item 3b

## Footnotes

As you write, you might want to footnote something.^[The footnote will be in a smaller font and enumerated and placed appropriately.] 
Alternatively, you can specify the footnote yourself.[^2]


[^2]: And then write the text out at the bottom of the page/document.

---
title: Methods
author: Author
chapter: 3
in_context: False
knit: iheiddown::chapter_pdf
output: iheiddown::chapter_pdf
---

\setcounter{chapter}{2}
# Methods {#methods}

Your methods section will discuss the approach you will take for your dissertation.

## Writing up math

\TeX\ is the best way to typeset mathematics. 
Donald Knuth designed \TeX\ when he got frustrated at how long it was taking the typesetters to finish his book, 
which contained a lot of mathematics.  
One nice feature of _RMarkdown_ is its ability to read LaTeX code directly.

If you are writing a thesis that includes equations, then this section will be useful.
If not, you can just skip over or delete this section 
(you can always come back to it later by creating a new templated folder or looking at this chapter on the GitHub account online.)

### In-line expressions

First, we can include short equations into our normal text by enclosing \LaTeX\ equations in dollar signs. 
So `$\sum_{i=1}^N i$` will read $\sum_{i=1}^N i$.

### Displayed expressions

\LaTeX\ also includes the option to present mathematical expressions on one or more separate lines:

$$
\pi(\theta|X_1< y_1,\dots,X_n<y_n) \varpropto \pi(\theta) \prod_{i=1}^n\int_{-\infty}^{y_i}
   \exp\left(-\frac{(x-\theta)^2}{2\sigma^2}\right)\ dx
$$


$$
\sum_{j=1}^n (\delta\theta_j)^2 \leq \frac{\beta_i^2}{\delta_i^2 + \rho_i^2}
\left[ 2\rho_i^2 + \frac{\delta_i^2\beta_i^2}{\delta_i^2 + \rho_i^2} \right] \equiv \omega_i^2
$$

Another equation:

$$\det\left|\,\begin{matrix}%
c_0&c_1\hfill&c_2\hfill&\ldots&c_n\hfill\cr
c_1&c_2\hfill&c_3\hfill&\ldots&c_{n+1}\hfill\cr
c_2&c_3\hfill&c_4\hfill&\ldots&c_{n+2}\hfill\cr
\,\vdots\hfill&\,\vdots\hfill&
  \,\vdots\hfill&&\,\vdots\hfill\cr
c_n&c_{n+1}\hfill&c_{n+2}\hfill&\ldots&c_{2n}\hfill\cr
\end{matrix}\right|>0$$


### Model equations

One hassle is writing \LaTeX\ equations for the models you run in your analysis.
Fortunately, there is an app (sic: package) for that!
[`{Equatiomatic}`](https://github.com/datalorax/equatiomatic) takes some of the pain out of that chore.
More details can be found [here](https://datalorax.github.io/equatiomatic/articles/intro-equatiomatic.html#other-models-1).

### Symbols

Many of the symbols you will need can be found on the [Comprehensive LaTeX Symbol Guide](https://mirror.utexas.edu/ctan/info/symbols/comprehensive/symbols-letter.pdf).

\noindent Exponent or Superscript: $\mathrm{O^-}$

\noindent Subscript: $\mathrm{CH_4}$

To stack numbers or letters as in $\mathrm{Fe_2^{2+}}$, the subscript is defined first, and then the superscript is defined.

\noindent Delta: $\Delta$

<!--
The \noindent command does what you'd expect:  
it forces the current line/paragraph to not indent. 
This was done here to match the format of the LaTeX thesis PDF.
-->

You can get around math mode's automatic italicizing in \LaTeX\ by using the argument `$\mathrm{formula here}$`, 
with your formula inside the curly brackets.  
(Notice the use of the backticks here which enclose text that acts as code.)

So, $\mathrm{Fe_2^{2+}Cr_2O_4}$ is written `$\mathrm{Fe_2^{2+}Cr_2O_4}$`.

## Inline code

If you'd like to put the results of your analysis directly into your discussion, add inline code like this:

> The `cos` of $2 \pi$ is `r cos(2*pi)`. 

Another example would be the direct calculation of the standard deviation:

> The standard deviation of `speed` in `cars` is `r sd(cars$speed)`.

One last neat feature is the use of the `ifelse` conditional statement which can be used to output text depending on the result of an **R** calculation:

> `r ifelse(sd(cars$speed) < 6, "The standard deviation is less than 6.", "The standard deviation is equal to or greater than 6.")`

Note the use of `>` here, which signifies a quotation environment that will be indented.

As you see with `$2 \pi$` above, mathematics can be added by surrounding the mathematical text with dollar signs.

This *RMarkdown* template is for writing a Graduate Institute thesis. 

This template's sample content include illustrations of how to write a thesis in *RMarkdown*, 
and largely follows the structure from [this R Markdown workshop](https://ulyngs.github.io/rmarkdown-workshop-2019/).

Congratulations for taking a step further into the lands of open, reproducible science 
by writing your thesis using a tool that allows you to transparently include tables and dynamically generated plots directly from the underlying data. 
Hip hooray!

---
title: "Title"
subtitle: "Subtitle"
author: "<large>Author Name</large>"
# institute: "<small>Geneva Graduate Institute</small>" # uncomment to include
# date: "`r format(Sys.Date(), '%A, %e %B, %Y')`" # uncomment to include
output:
  xaringan::moon_reader:
    css: 
      - "default"
      - "assets/iheid-xaringan-style.css"
      - "https://cdnjs.cloudflare.com/ajax/libs/animate.css/4.1.1/animate.min.css"
      - "ninjutsu"
    chakra: "https://remarkjs.com/downloads/remark-latest.min.js"
    # if you want to work offline, run the following command...
    # xaringan::summon_remark()
    # ...and then comment out lines 10-13 and uncomment lines 14-15:
    # lib_dir: libs
    # chakra: libs/remark-latest.min.js # For offline
    nature:
      ratio: '16:9'
      highlightStyle: github
      highlightLines: true
      beforeInit: "assets/macros.js"
      countIncrementalSlides: false
      slideNumberFormat: |
        <div class="progress-bar-container">
          <div class="progress-bar" style="width: calc(%current% / %total% * 100%);">
          </div>
        </div>`
---
class: center, middle

# With this template, it is very easy to build good looking slides

## and you can centre everything for title/section/other slides

```{r setup, include=FALSE}
# don't mind this code chunk, it just sets up a few things for the rest
# it doesn't appear, because the include argument above is FALSE...
options(htmltools.dir.version = FALSE, servr.daemon = TRUE)
knitr::opts_chunk$set(cache=TRUE, autodep = TRUE, fig.retina = 3, message = FALSE, warning = FALSE)
old <- ggplot2::theme_set(iheiddown::theme_iheid())
```

```{r, load_refs, include=FALSE, cache=FALSE}
# Initializes the bibliography
library(RefManageR)
BibOptions(check.entries = FALSE,
           bib.style = "authoryear", # Bibliography style
           max.names = 3, # Max author names displayed in bibliography
           sorting = "nyt", #Name, year, title sorting
           cite.style = "authoryear", # citation style
           style = "markdown",
           hyperlink = FALSE,
           dashed = FALSE)
myBib <- ReadBib("assets/myBib.bib", check = FALSE)
# Note: don't forget to clear the knitr cache to account for changes in the
# bibliography.
```

---
class: middle, inverse, iheid-red

## You can colour the background and add images using straightforward markdown syntax

.center[
.polaroid[![](https://graduateinstitute.ch/sites/default/files/styles/medium/public/2019-01/James%20Hollway.jpg?itok=1Yw0keum)]

James Hollway (Instructor)
]

---
## You can also pull images (or text) to the left or right to build columns

.pull-left[
.polaroid[![](https://graduateinstitute.ch/sites/default/files/styles/medium/public/2019-01/James%20Hollway.jpg?itok=1Yw0keum)]

James Hollway (Instructor)
]

.pull-right[
I can add paragraphs of extra information...

or a bullet list...

- one
- two
- three

or a numbered list...

1. one
1. two
4. three
]

---
class: split-four, center

# Present your team by slicing the slide up with ninjutsu!

.column[.pull-down[![:scale 75%](https://www.seekpng.com/png/detail/143-1435868_headshot-silhouette-person-placeholder.png)

*Prof. Smith*

Principal Investigator

]]
.column[.pull-down[![:scale 75%](https://www.seekpng.com/png/detail/143-1435868_headshot-silhouette-person-placeholder.png)

*Dr. Jones*

Doctoral Research Assistant

]]
.column[.pull-down[![:scale 75%](https://www.seekpng.com/png/detail/143-1435868_headshot-silhouette-person-placeholder.png)

*Ms. Dupont*

Research Assistant

]]

.column[.pull-down[![:scale 75%](https://www.seekpng.com/png/detail/143-1435868_headshot-silhouette-person-placeholder.png)

*Mr. Dupond*

Research Assistant

]]

---
## You can build a step-by-step reveal

--

By using double dashes `--` to separate lines of text or code,
we can build a slide up gradually.
--

For example here is some more text...
--

Or here is an example of some math...

$$ X = \sum_i^n x_i $$

--

Or here is a quick plot built (and cached) when the Rmarkdown document is run:

```{r, fig.height=4}
plot(iris)
```

---
class: highlight-last-item

## Add progressive lists

Adding the class `highlight-last-item` allows you to highlight the last element
of a progressive list.

- First item

--

- Second item

--

-  For more options, see the `iheid-xaringan-style.css` file and search for
"progressive slides". This feature was based on [this great article](https://www.garrickadenbuie.com/blog/better-progressive-xaringan/?panelset2=r-markdown3&panelset=r-markdown&panelset1=slides2).

---
class: show-only-last-code-result

## Progressive code

Adding the class `show-only-last-code-result` allows you to render only the last
code result.

```{r}
runif(5)
```
--

```{r}
rnorm(5)
```
--

```{r}
rbinom(5, 1, 0.5)
```
--

```{r}
rcauchy(5)
```

---
class: center, middle
## Or you can highlight which section of your presentation you are up to...

.pull-1[.circleoff[![](https://upload.wikimedia.org/wikipedia/commons/thumb/3/3f/NYCS-bull-trans-1.svg/1024px-NYCS-bull-trans-1.svg.png)]]
.pull-1[.circleon[![](https://upload.wikimedia.org/wikipedia/commons/thumb/6/61/NYCS-bull-trans-2.svg/1200px-NYCS-bull-trans-2.svg.png)]]
.pull-1[.circleoff[![](https://upload.wikimedia.org/wikipedia/commons/thumb/2/25/NYCS-bull-trans-3.svg/1200px-NYCS-bull-trans-3.svg.png)]]

---
class: left, middle

.blockquote[You can add unquotable quotes

~ Some person]

---
class: with-logo logo-iheid

## Add a logo to your presentation 

.pull-left[Adding a nice looking logo to your presentation is easy. Simply 
define the `with-logo` class alongside the class of the logo itself 
(`logo-iheid` in this case) on every slide you want the logo to appear.

See [the presentation vignette](https://github.com/iheid-library/iheiddown) for a
list of the included logos.]

---

## Add Maps

```{r, fig.height=4, fig.width=10, fig.align='center', echo=TRUE}
library(leaflet)
leaflet() %>%
  addTiles() %>%
  setView(6.1435, 46.2210, zoom = 17)
```

---

## Add some tables !

With the addition of the excellent [`{xaringan_columns}`](https://github.com/emilyriederer/xaringan_columns) macros by Emily
Riederer, you can create nice looking multicolumn tables using clean markdown code.

![:col_header Header 1, Header 2, Header 3, Header 4, Header 5]
![:col_list You can add rows with bulletted lists, item2, item3, hello, more content]
![:col_list item4, item5, Or normal chunks of text (see below), la la la, tra la la]
![:col_row 
    More text,
    More text,
    .,
    More text,
    More text
]

---

## More tables; kable and kableExtra packages
.pull-left[Kable: great features for displaying simple tables!
```{r, fig.height = 4, fig.width=10, echo=TRUE}
knitr::kable(head(mtcars[1:4], 5), format = 'html')
```

See [the knitr documentation](https://yihui.org/rmarkdown-cookbook/kable.html)
for additional options.
]

.pull-right[Want to get fancier? Use kableExtra!
```{r, fig.height = 2, fig.width=2, echo=TRUE}
head(mtcars[1:4], 3) %>% 
  kableExtra::kbl()%>%
  kableExtra::kable_material(c("hover", "striped", "condensed"), full_width = F)
```

See [the kableExtra documentation](https://cran.r-project.org/web/packages/kableExtra/vignettes/awesome_table_in_html.html)
for additional options.
]

---

## Interactive tables; DT package

```{r, fig.height = 4, fig.width=10, echo=TRUE}
library(DT)
DT::datatable(head(mtcars, 10),
  fillContainer = FALSE, options = list(pageLength = 4))
```

See the [DT package documentation](https://rstudio.github.io/DT/) for the
additional options.

---
# Adding tweets

Embed tweets in your presentation!

.center2[
<blockquote class="twitter-tweet" data-lang="de"><p lang="en" dir="ltr">You&#39;re doing it right if you get frustrated: if you&#39;re not frustrated, you&#39;re (probably) not stretching yourself mentally</p>&mdash; Hadley Wickham (@hadleywickham) <a href="https://twitter.com/hadleywickham/status/565516733516349441?ref_src=twsrc%5Etfw">11. Februar 2015</a></blockquote>
]

---
class: animate__animated, animate__slideInRight

## Add slide transitions to  your slides

Simply add the class `animate__animated` and the class corresponding to the
desired animation such as `animate__slideInRight`, et voilà!

For a complete list of the available animations and further options, visit
[animate.style](https://animate.style/).

.center[![Animation GIF](https://i.giphy.com/media/Oo6GWyiWEDgtO/giphy.webp)]

---
background-image: url(https://media1.giphy.com/media/xT0BKiK5sOCVdBUhiM/giphy.gif)
background-size: contain

# And finally, you can add gifs!

---
class: inverse iheid-red center middle with-logo logo-iheid_BW

Made with `{iheiddown}`, the R-package for IHEID publications
`r Cite(myBib, "iheiddown")`.

---

# References

```{r refs, echo=FALSE, results="asis"}
RefManageR::PrintBibliography(myBib)
```

---
title: "Posters"
author: "Bernhard Bieri"
date: "`r Sys.Date()`"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{Posters}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r global.options, include = FALSE}
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>",
  fig.align = 'center',
  fig.width = 6,
  fig.height = 4
)
```

```{r setup, include=FALSE}
pkgs <- c("iheiddown", "magrittr", "ggplot2")
lapply(pkgs, library, character.only = TRUE)
```

While `{iheiddown}`'s main aim is to assist students in writing their thesis, it
can also be used for showcasing projects or papers at conferences with its
poster template. This short article will walk you through the process of using
the IHEID-themed poster templates.

## Installation

The installation process is the same than for the thesis template. You'll need
the following software:

1. Install [R](https://cran.r-project.org) and [R-Studio](https://posit.co/)
2. Install a LATEX distribution:
    - [For MacOS](https://www.tug.org/mactex/)
    - [For Windows](https://miktex.org/)
    - [For Linux](https://www.tug.org/texlive/)
3. Install `{iheiddown}` by typing the following command
`install.packages("iheiddown") ` in the R-Studio console. 

Note: typing `remotes::install_github("jhollway/iheiddown")` will provide you
with the latest version from GitHub.

## Create your first poster

Creating your first poster is easy! Before we begin, we have to create a
new R project by clicking on the file tab in the
top of the RStudio window and following the instructions of the prompt that
appears. Now that we have created an R project for our presentation, we can open
a new R-Markdown file. To do this click on the "plus file" logo in the top left
corner and then on "R-Markdown".

```{r, echo = FALSE, out.width="80%", fig.cap="Step 1: Open a project"}
knitr::include_graphics("images/poster/0-Open_Project.png", dpi = 144)
```

After you have done this, a little pop-up helper will appear. The first thing we
will do is to select the `{iheiddown}` template for our presentation. To do so,
click on the "From Template" option on the left and select one of the
"Poster {iheiddown}" templates. Now give your poster a name and click
on "OK".

```{r, echo = FALSE, out.width="80%", fig.cap="Step 2: Select a template"}
knitr::include_graphics("images/poster/select_template.png", dpi = 144)
```

Congrats! You just created your first poster! Let's render it to see what it
looks like out of the box. This is done by simply clicking the "knit button"
while viewing the `Poster.Rmd` pane. Et voilà! You have now successfully
generated your first poster with R.

Take a moment to read through the generated poster to get acquainted
with the `{R-markdown}` syntax and to get a feel of the possibilities of the
`{iheiddown}` theme.

## Edit your poster

This section will focus on giving you an overview of the workflow of designing
your conference posters in R with`{iheiddown}`.

### Three flavors of posters to choose from:

The three flavors `{iheiddown}` incorporates are "re-themed" versions of
the excellent [`{posterdown}`](https://github.com/brentthorne/posterdown)
package. They include:

- A classic poster (landscape)
  - Simple and classic poster layout.
- A "betterposter" (landscape)
  - Inspired by Mike Morrison's template allowing you to highlight the central
  message of your poster in a landscape format.
- A "betterposter" (portrait)
  - Inspired by Mike Morrison's template allowing you to highlight the central
  message of your poster in a portrait format.

Here is the thread that started the [`#betterposter`](https://x.com/mikemorrison/status/1110191245035479041?s=20&t=s3laifia16m89VYH_EMEqA) style. Choose the one that fits your needs and read on to discover how to edit it!

### Set YAML options

The general options are set in the YAML header. You can define the metadata of
the document such as the name of the authors, the institution they are a part of
, and the title of your poster there.

You can also set bibliographic options such as the `.bib` file you want to draw
your references from (`packages.bib` by default) and the style of the
bibliographic entries by altering the `.csl` file. Note that packages that were
used in the code chunks of your problem set have their citation information
automatically written to a second `.bib` file called `packages.bib`. That way
you easily give appropriate credit to the work of the creators of the packages
you use.

That's it! You're now all set to focus on the content of your poster.
Again, please take a moment to read through the template once it
is generated as it serves as much as a tutorial than this vignette.

### Printing your posters

Printing your posters can be done by opening the generated HTML file in any
modern browser and select the "print to PDF" functionality they incorporate.

---
title: "Creating presentations"
author: "Bernhard Bieri"
date: "`r Sys.Date()`"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{Creating presentations}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r global.options, include = FALSE}
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>",
  fig.align = 'center',
  fig.width=6,
  fig.height=4
)
```

```{r setup, include=FALSE}
pkgs <- c("iheiddown", "magrittr", "ggplot2")
lapply(pkgs, library, character.only = TRUE)
```

`{iheiddown}` not only allows its users to create scholarly documents but also
provides them with a simple way to create great presentations to share the
contents of their research effectively. This article will help you get started
from the ground up and help you create your very own first presentation.

## Installation

The presentation theme is based on Yihui Xie's excellent
[`{xaringan}`](https://github.com/yihui/xaringan) package. Hence the first thing
to do is to install the necessary components as well as `{iheiddown}` itself.
Note that we can also install the latest version of the package from GitHub
directly by using `remotes::install_github("jhollway/iheiddown")`.

```{r, eval = F, echo = T}
# Install the required packages
install.packages("iheiddown")
remotes::install_github("yihui/xaringan")
install.packages("servr") # This will allow us to see the slides we are editing

# Load the packages in your session
pkgs <- c("iheiddown", "xaringan", "servr")
lapply(pkgs, library, character.only = TRUE)
```

Before we go any further, we should introduce
[`{xaringan}`](https://github.com/yihui/xaringan) a bit more since you'll be
working with when creating presentations with the `{iheiddown}` theme.
The first thing to know is that there are many ways to create presentations in
(R-)Markdown and that there is not one solution that fulfills all needs.
However, after careful consideration (and reading
[this blog post](https://yihui.org/en/2017/08/why-xaringan-remark-js/)) we
settled on `{xaringan}`to develop our presentation template for.

If you want to know more about `{xaringan}` and other presentation packages for
R, check out
[this excellent book](https://yihui.org/rmarkdown/xaringan.html).

## Create your first presentation

Creating your first presentation is easy! Let's look at how it is done. Before
we begin, we have to create a new R project by clicking on the file tab in the
top of the RStudio window and following the instructions of the prompt that
appears. Now that we have created an R project for our presentation, we can open
a new R-Markdown file. To do this click on the "plus file" logo in the top left
corner and then on "R-Markdown".

```{r, echo = FALSE, out.width="80%", fig.cap="Step 1: Open a project"}
  knitr::include_graphics("images/presentations/0-OpenProject.png", dpi = 144)
```

After you have done this, a little pop-up helper will appear. The first thing we
will do is to select the `{iheiddown}` template for our presentation. To do so,
click on the "From Template" option on the left and select the
"Presentation {iheiddown}" template. Now give your presentation a name and click
on "OK".

```{r, echo = FALSE, out.width="80%", fig.cap="Step 2: Select a template"}
  knitr::include_graphics("images/presentations/1-SelectTemplate.png", dpi = 144)
```

Congrats! You just created your first presentation!

Hold on, this doesn't look anything like slides!? To see your slides,
you have to "knit" the code by clicking on the little "knit" button on the
presentation.Rmd file. This will run all the code chunks and convert
the markdown code to an HTML presentation that you will be able to share with
your audience.

Take a moment to flick through the slides to get acquainted with the
`{R-markdown}` syntax and to get a feel of the possibilities of `{xaringan}` and
the `{iheiddown}` theme. These slides are as much a tutorial as this vignette!


## Edit your presentation

This section will focus on giving you an overview of what a `{xaringan}`
presentation is comprised of and give you a few tips and tricks to edit your
presentations.

### Your first edit

As you may have noticed by now, `{xaringan}` presentations are not quite like
more traditional WYSIWYG (what you see is what you get) presentation tools like
PowerPoint. In short, you write in the R-markdown file, define style classes in
the CSS files and create macros in the JavaScript file. This is all a bit
confusing isn't it? Thankfully, there is a way to vizualise your edits easily in
real time!

```{r, eval=FALSE, echo=TRUE}
# Install/Load the servr package if you haven't done it already
install.packages("servr")
library(servr)

# Serve your {xaringan} presentation to see live updates when you edit
iheiddown::preview_start()

# Close the connection to the live rendering when you're done
iheiddown::preview_stop()
```

`{xaringan}` includes a handy function called `inf_mr()` which will work in
concert with the `{servr}` package to render your sites locally and update them
as soon as you save your markdown document. We simply wrapped these functions
inside the more convenient `{iheiddown}` versions: `preview_realtime()` and
`preview_stop()`. This makes it a lot easier to edit your slides!

### The different elements of a `{xaringan}` presentation

`{xaringan}` presentations are comprised of three main components:

- The main .Rmd file for raw content
- The CSS file for style and layout options
- The macros.js file for handy functions

The main .Rmd file will be the core of your presentation, since it is where you
will write the text, run R code chunks, and [display gifs](https://www.bbc.com/culture/article/20170825-how-the-gif-won-the-internet)
to entertain your audience.

The CSS file contains all the styling options that will be used to display the
the content of the `.Rmd` file in a nice manner. This file contains the
definitions of all the classes we use in the presentation.

Finally, the `macros.js` file specifies small functions used for specific cases.
An example of a macro would be the inclusion of
[Emily Riederer's `xaringan_columns` macros](https://github.com/emilyriederer/xaringan_columns).

Note that editing the CSS and the macros files is not recommended for beginner
users as the point of having a theme is to avoid having to fiddle with these
files. Advanced users who wish to contribute a feature should [open an issue on
Github](https://github.com/iheid-library/iheiddown/issues) to suggest the additional
features.

### Tips and tricks for editing your presentations 

The following sections cover additional tips and tricks that are not mentionned
in the slides. You'll discover how to animate your slides and how to include a
bibliography.

#### Slide transitions

For ease of use, we have included the
[`{animate.style}`](https://animate.style/) library of CSS animations. This
allows us to easily animate our slides with the addition of the CSS class
`animate__animated` and the desired animation e.g. `animate__slideInRight` on
the desired slide.

For a full list of the available animations and further options, check out
[animate.style](https://animate.style/).

#### Adding IHEID logos

We implemented an easy way of including logos from the institute in the top
right corner of your presentation. Simply add the `with-logo` CSS class along
the specific logo's class at the top of a given slide! Here is a list of
the logos currently available in the package.

| Logo                | Selector          |
| ------------------- |:-----------------:|
| IHEID               | logo-iheid        |
| IHEID (white text)  | logo-iheid_white  |
| IHEID (BW)          | logo-iheid_BW     |
| Executive Education | logo-ee           |
| AHCD                | logo-ahcd         |
| CCDP                | logo-ccdp         |
| CFD                 | logo-cfd          |
| CIES                | logo-cies         |
| CTEI                | logo-ctei         |
| GENDER              | logo-gender       |
| GGC                 | logo-ggc          |
| GHC                 | logo-ghc          |
| GMC                 | logo-gmc          |

If you think of an IHEID related logo that you would like to add to this
collection, feel free to [raise an issue](https://github.com/iheid-library/iheiddown/issues)
and link to the logo resource.

#### Citations and Bibliography

We all stand on the shoulders of giants when we are conducting research. This
is why we have implemented an easy way of generating citations and adding a
bibliography to your presentation. 
Note that this method uses the package `{RefManageR}` that you will need to
install.

``` {r, echo = TRUE, eval = F}
install.packages("RefManageR")
```

The first step to adding a bibliography is to define its options in a code
chunk at the very top of your `presentation.Rmd` file. 

```{r, eval=FALSE, echo = TRUE}
# Initializes the bibliography
library(RefManageR)
BibOptions(check.entries = FALSE,
           bib.style = "authoryear", # Bibliography style
           max.names = 3, # Max author names displayed in bibliography
           sorting = "nyt", #Name, year, title sorting
           cite.style = "authoryear", # citation style
           style = "markdown",
           hyperlink = FALSE,
           dashed = FALSE)
myBib <- ReadBib("myBib.bib", check = FALSE)
# Note: don't forget to clear the knitr cache to account for changes in the
# bibliography.
```

The second step is to cite the papers you want to cite inline with `Citet()`,
`Citep()`, `AutoCite()` or `NoCite()`. Here is an example:
`Citet(myBib, "Entry_Name")`. Note that every element that you wish to put in
the bibliography at the end must be cited. Hence, if you only want a
bibliographical element to appear in the bibliography but not as a citation on
one of your slides, use the `NoCite()` function.

The third and final step is to print the full bibliography in the last slides
of your presentation.

````md
```{r refs, echo=FALSE, results="asis"}`r ''`
PrintBibliography(myBib)
```
````

Finally, note that you can specify the number of references you want to print
on each slide to avoid overfilling them. 

````md
```{r refs, echo=FALSE, results="asis"}`r ''`
PrintBibliography(bib, start = 1, end = 7)
```
````

For more in depth information about the integration of bibliographic
information into your presentations, please visit
[this wiki](https://github.com/yihui/xaringan/wiki/Bibliography-and-citations).

## Presenting

After creating your presentation, it is time to share it with the world!
To do so, simply open the HTML file that was created in your project folder
after you knitted it.

`{xaringan}` provides you with nifty shortcuts to toggle presenter mode (p) or
duplicate the slides (c) to present them on a second screen. Clicking "h" will
pull up the entire list of shortcuts. Present away!

## Printing the slides

There are two main ways to print slides.

- Print the slides that you rendered after opening them in your browser just like you would print a normal Web page.
  - Works best in the Google Chrome browser
- Use `pagedown::chrome_print()` when viewing your Rmarkdown file
- Use `xaringan_to_pdf()` an extended printing function that works especially
  well for complex slide decks. You can find this function in
  [this great blog article](https://www.garrickadenbuie.com/blog/print-xaringan-chromote/)
  by Garrick Aden Buie.

## Additional resources

### A non-exhaustive list of additional readings and extensions 

- Readings
  - [`{Xaringan}` documentation](https://yihui.org/rmarkdown/xaringan.html)
  - [Markdown cheatsheet](https://github.com/adam-p/markdown-here/wiki/Markdown-Cheatsheet)
  - [R Markdown: The Definitive Guide](https://yihui.org/rmarkdown/)
  - [Garrick Aden-Buie's website](https://www.garrickadenbuie.com/)
- Extensions
  - [`{xaringanExtra}`](https://github.com/gadenbuie/xaringanExtra)
    - A collection of neat extensions to make your presentation even prettier/
    more functional
  - [`{flipbookr}`](https://evamaerey.github.io/flipbookr/)
    - `{flipbookr}` aims to remove some of the confusion that might arise when
    showcasing large chunks of code by taking a step by step approach.

---
title: Generate Reproducible & Live HTML and PDF Conference Posters Using RMarkdown
author:
  - name: Gandalf the Grey
    affil: 1
    orcid: '0000-0002-1825-0097'
  - name: Frodo Baggins
    affil: 2
affiliation:
  - num: 1
    address: Department of International Ring Study, Central University of Middle Earth
  - num: 2
    address: Department of Dragon Studies, Northern University of Middle Earth
column_numbers: 3
logoright_name: https&#58;//raw.githubusercontent.com/jhollway/iheiddown/main/man/figures/iheiddown.png
logoleft_name: https&#58;//raw.githubusercontent.com/jhollway/iheiddown/main/man/figures/iheiddown.png
output: 
  iheiddown::iheiddown_poster:
    self_contained: false
bibliography: packages.bib
---

```{r setup, include=FALSE}
knitr::opts_chunk$set(echo = FALSE)
```

# Introduction

Welcome to the `{iheiddown}` twist of the great `{posterdown}` poster template !
This poster, alongside their `#betterposter` versions, allow students and
researchers to create IHEID-themed posters easily within R. The remaining part
of this template allows you to get familiar with its layout. Head over to
`{posterdown}` if you fancy having a look at the original version!

## Objectives

1. Easy to use reproducible poster design. 
2. Integration with R Markdown.
3. Easy transition from `{iheiddown}` to `{pagedown}` report or manuscript documents [@R-pagedown].

# Methods

This package uses the same workflow approach as the R Markdown you know and love. Basically it goes from RMarkdown > Knitr > Markdown > Pandoc > HTML/CSS > PDF. You can even use the bibliography the same way [@iheiddown].

# Results

Usually you want to have a nice table displaying some important results that you have calculated. In `{iheiddown}` this is as easy as using the `{kable}` table formatting you are probably use to as per typical R Markdown formatting.

You can reference tables like so: Table \@ref(tab:mytable). Lorem ipsum dolor sit amet, consectetur adipiscing elit. Aliquam placerat augue at velit tincidunt semper. Donec elementum porta posuere. Nullam interdum, odio at tincidunt feugiat, turpis nisi blandit eros, eu posuere risus felis non quam. Nam eget lorem odio. Duis et aliquet orci. Phasellus nec viverra est.

```{r mytable, out.width='80%'}
knitr::kable(iris[1:10, 1:4], caption = 'Table caption.',align = 'c',"html")
```

Or with figures: Figure \@ref(fig:standard-plot), or Figure \@ref(fig:morefigs).

```{r standard-plot, out.width='80%', fig.align='center', fig.cap='Great figure!', fig.height=5}
plot(mtcars[1:2])
```

```{r morefigs, out.width='80%', echo=TRUE, fig.cap='Amazing, right?!', fig.height=5}
data <- iris

plot(x = data$Sepal.Length, 
     y = data$Sepal.Width, 
     col = data$Species,
     pch = 19, 
     xlab = "Sepal Length (cm)",
     ylab = "Sepal Width (cm)")

```

# Next Steps

Aliquam sed faucibus risus, quis efficitur erat. Vestibulum semper mauris quis tempus eleifend. Aliquam sagittis dictum ipsum, quis viverra ligula eleifend ut. Curabitur sagittis vitae arcu eget faucibus. In non elementum felis. Duis et aliquam nunc. Nunc pulvinar sapien nunc, vel pretium nisi efficitur in. Fusce fringilla maximus leo et maximus. Fusce at ligula laoreet, iaculis mi at, auctor odio. Praesent sed elementum justo. Aenean consectetur risus rhoncus tincidunt efficitur. Praesent dictum mauris at diam maximus maximus [@R-iheiddown].

# Conclusion

Try `{iheiddown}` out! Hopefully you like it!

```{r, include=FALSE}
knitr::write_bib(c('knitr','rmarkdown','iheiddown','pagedown', 'posterdown'), 'packages.bib')
```

# References

---
main_topsize: 0.2 #percent coverage of the poster
main_bottomsize: 0.1
#ESSENTIALS
title: '**A Better Reproducible Poster Title**'
author:
  - name: '**Gandalf the Grey**'
    affil: 1
    main: true
    orcid: '0000-0002-1825-0097'
    twitter: IHEID
    email: example@example.ch
  - name: Frodo Baggins
    affil: 2
    main: true
    email: 'ag.con@iheiddown.net'
  - name: Bilbo
    affil: 3
affiliation:
  - num: 1
    address: Department of International Ring Study, Central University of Middle Earth
  - num: 2
    address: Department of Dragon Studies, Northern University of Middle Earth
  - num: 3
    address:  Department of Wraith-World Studies, Eastern University of Middle Earth
main_findings:
  - "Make **better posters** with RMarkdown + **{iheiddown}**."
logoleft_name: https&#58;//raw.githubusercontent.com/jhollway/iheiddown/main/man/figures/iheiddown.png
logoright_name: https&#58;//raw.githubusercontent.com/jhollway/iheiddown/main/man/figures/iheiddown.png
logocenter_name: https&#58;//raw.githubusercontent.com/jhollway/iheiddown/main/man/figures/iheiddown.png
output: 
  iheiddown::iheiddown_betterport:
    self_contained: false
    pandoc_args: --mathjax
    number_sections: false
bibliography: packages.bib
link-citations: true
---

```{r, include=FALSE}
knitr::opts_chunk$set(echo = FALSE,
                      warning = FALSE,
                      tidy = FALSE,
                      message = FALSE,
                      fig.align = 'center',
                      out.width = "100%")
options(knitr.table.format = "html") 
```

# Introduction

This is the `iheiddown_betterport` template for the `{iheiddown}` [@iheiddown] package!
Based on the great `{posterdown}` package, it provides the user with an IHEID
version of the template by default. The original `{posterdown}` template was
inspired by the twitter thread of
[Mike Morrison](https://mobile.twitter.com/mikemorrison/status/1110191245035479041).

```{r, include=FALSE}
# Writing the bibliography of the packages you're using to create the current
# poster is a great way to give credit to the authors of the packages you're
# using.
knitr::write_bib(c('iheiddown',
                   'rmarkdown',
                   'posterdown',
                   'iheiddown'),
                 'packages.bib')
```

## Objectives

1. Pick a template layout.
2. Write/ create your poster content distraction free.
3. Press `CTRL+K` and let `{iheiddown}` do its thing!

Read the guide below (mostly identical to posterdown). It will make you
familiar with the ways of creating a great poster.

# Methods

I will show here how to include poster elements that may be useful, such as an
equation using mathjax:

$$
E = mc^2
$$

To reference a citation you can add your `.bib` file to the working directory
and name it in the YAML metadata or generate an automated one as done here,
then you only need to reference the label value in the `.bib` file. For example
this package is built on top of the wonderful {pagedown} package and I will
cite it at the end of this sentance using this in the rmd `[@R-pagedown]` [@R-pagedown].

To get a better understanding of how to include features like these please
refer to the {iheiddown} [wiki](https://github.com/iheiddown/wiki).

**_Now on to the results!_**

# Results

Here you may have some figures to show off, bellow I have made a scatterplot
with the infamous Iris dataset and I can even reference to the figure
automatically like this, `Figure \@ref(fig:irisfigure)`, Figure
\@ref(fig:irisfigure).

```{r, irisfigure, fig.cap='Here is a caption for the figure. This can be added by using the "fig.cap" option in the r code chunk options, see this [link](https://yihui.name/knitr/options/#plots) from the legend himself, [Yihui Xie](https://twitter.com/xieyihui).', out.width="80%"}
par(mar=c(2,2,0,1))
plot(x = iris$Sepal.Length, y = iris$Sepal.Width,
     col = iris$Species, pch = 19, xlab = "Sepal Length",
     ylab = "Sepal Width")
```

Maybe you want to show off some of that fancy code you spent so much time on
to make that figure, well you can do that too! Just use the `echo=TRUE` option
in the r code chunk options, Figure \@ref(fig:myprettycode)!

```{r myprettycode, echo=TRUE, fig.cap='Boxplots, so hot right now!', fig.height=6, out.width="80%"}
#trim whitespace
par(mar=c(2,2,0,0))
#plot boxplots
boxplot(iris$Sepal.Width~iris$Species,
        col = "#ed2215", 
        border = "#800000",
        ylab = "Sepal Width (cm)",
        xlab = "Species")
```

How about a neat table of data? See, Table \@ref(tab:iristable):

```{r, iristable}
knitr::kable(
  iris[1:15,1:5], format = "html",
  caption = "A table made with the **knitr::kable** function.",
  align = "c", col.names = c("Sepal <br> Length",
                             "Sepal <br> Width",
                             "Petal <br> Length",
                             "Petal <br> Width",
                             "Species"),
  escape = FALSE)
```

# References

---
title: Conclusion
author: Author
chapter: 5
in_context: False
knit: iheiddown::chapter_pdf
output: iheiddown::chapter_pdf
---

\setcounter{chapter}{4}
# Conclusion {#conclusion}

In sum, `{iheiddown}` offers an easy way to write IHEID-consistent theses,
but is enormously extensible and adaptable, 
allowing students to craft their own dissertations and other documents.

## Using iheiddown for proposals

As an example of this, let us consider how one might begin using iheiddown
from the start of a masters or doctoral dissertation,
and not just at the end while 'writing up' (a good idea in any case).

One feature often requested by supervisors from DDPs and MPTs
is the preparation of a plan about how and when the various tasks
associated with the project will be completed.
Your supervisor may even ask for this to be presented in a table or a Gantt chart.

We have covered tables in the previous chapter.
Here I want to offer a quick vignette about how you can create a Gantt chart
that outlines the temporal progression you expect to make.
We will use the `{gantrify}` package to do this.

```{r }
library("ganttrify")
ganttrify(project = ganttrify::test_project,
          project_start_date = "2020-03",
          colour_palette = iheiddown::iheid_palette("Centres", 
                                                    type = "continuous")
          )
```

## Additional resources

- [_Markdown_ Cheatsheet](https://github.com/adam-p/markdown-here/wiki/Markdown-Cheatsheet)

- _RMarkdown_
    - [Reference Guide](https://www.rstudio.com/wp-content/uploads/2015/03/rmarkdown-reference.pdf)
    - [Cheatsheet](https://github.com/rstudio/cheatsheets/raw/master/rmarkdown-2.0.pdf)
    - [For newbies](https://rbasics.netlify.com) 


- _RStudio IDE_
    - [Official website](https://rstudio.com/products/rstudio/)
    - [Cheatsheet](https://github.com/rstudio/cheatsheets/raw/master/rstudio-ide.pdf)

- [`dplyr`](https://cran.rstudio.com/web/packages/dplyr/vignettes/dplyr.html)

- `ggplot2`
    - [Documentation](https://ggplot2.tidyverse.org/)
    - [Cheatsheet](https://github.com/rstudio/cheatsheets/raw/master/data-visualization-2.1.pdf)

- [`bookdown`](https://yihui.org/bookdown/)

## Anything else?

If you'd like to see examples of other things in this template, 
please add them as feature requests to the [iheiddown](https://github.com/iheid-library/iheiddown) website. 
We love to see people using _RMarkdown_ for their theses, and are happy to help.

---
title: "Writing your syllabus"
author: "Bernhard Bieri"
date: "`r Sys.Date()`"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{Writing your syllabus}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r global.options, include = FALSE}
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>",
  fig.align = 'center',
  fig.width=6,
  fig.height=4
)
```

```{r setup, include=FALSE}
pkgs <- c("iheiddown", "magrittr", "ggplot2")
lapply(pkgs, library, character.only = TRUE)
```

`{iheiddown}` is not only a tool for students to write their thesis in. It can
also be of use for teaching activities at IHEID as it harbors a great looking
template for course syllabi. This short article will walk you through the
workflow of writing your very own syllabus in R.

## Installation

The installation process is the same than for the thesis template. You'll need
the following software:

1. Install [R](https://cran.r-project.org) and [R-Studio](https://posit.co/)
2. Install a LATEX distribution:
    - [For MacOS](https://www.tug.org/mactex/)
    - [For Windows](https://miktex.org/)
    - [For Linux](https://www.tug.org/texlive/)
3. Install `{iheiddown}` by typing the following command
`install.packages("iheiddown") ` in the R-Studio console. 

Note: typing `remotes::install_github("jhollway/iheiddown")` will provide you
with the latest version from GitHub.

## Create your first syllabus 

Creating your first syllabus is easy! Let's look at how it is done. Before
we begin, we have to create a new R project by clicking on the file tab in the
top of the RStudio window and following the instructions of the prompt that
appears. Now that we have created an R project for our presentation, we can open
a new R-Markdown file. To do this click on the "plus file" logo in the top left
corner and then on "R-Markdown".

```{r, echo = FALSE, out.width="80%", fig.cap="Step 1: Open a project"}
  knitr::include_graphics("images/syllabus/0-OpenProject.png", dpi = 144)
```

After you have done this, a little pop-up helper will appear. The first thing we
will do is to select the `{iheiddown}` template for our presentation. To do so,
click on the "From Template" option on the left and select the
"Syllabus {iheiddown}" template. Now give your file a name and click
on "OK".

```{r, echo = FALSE, out.width="80%", fig.cap="Step 2: Select a template"}
  knitr::include_graphics("images/syllabus/1-CreateSyllabus.png", dpi = 144)
```
Congrats! You just created your first syllabus! We can actually already render
our syllabus. This is done by simply clicking the "knit button" while viewing
the `MySyllabus.Rmd` pane. Et voilà! You have now successfully generated your
first syllabus with R.

Take a moment to read through the generated syllabus to get acquainted with the
`{R-markdown}` syntax and to get a feel of the possibilities of the
`{iheiddown}` theme.

## Edit your syllabus

This section will focus on giving you an overview of the workflow of creating
your syllabus with the `{iheiddown}` package.

### Set YAML options

The general options are set in the YAML header. You can define the contact
information of the instructor and the teaching assistant as well as give a
general course description or set evaluation policies. 

You can also set bibliographic options such as the `.bib` file you want to draw
your references from (`references.bib` by default) and the style of the
bibliographic entries by altering the `.csl` file.

### Setting the start-date of your course

The second step is to set the correct start date of your course in the main
`MySyllabus.Rmd` file. This is done simply by editing the `startdate` variable
in the first code chunk.

### Editing your course description

The third and last step is to edit the main body of the syllabus. To do this,
simply write the title of each week's session, a description if necessary and
add citations of the weeks material with the id of the reference in the bib file
preceded by "@" e.g. `@Darwin1958`.

This is where you normally thank your advisor, colleagues, family and friends, as well as funding and institutional support. 
In our case, we will acknowledge here those who developed the ideas and tools that allow us to push open science a little step further 
by writing plain-text, transparent, and reproducible theses in *RMarkdown*. 

First, we thank Leslie Lamport for originally creating \LaTeX\, 
and Frank Mittelbach, Chris Rowley, and Rainer Schöpf for their ongoing development.
Thank you to John Gruber for inventing the original version of Markdown, 
to John MacFarlane for creating Pandoc (<http://pandoc.org>), 
which converts Markdown to a large number of output formats including \LaTeX\.

Next, we are grateful to Ross Ihaka and Robert Gentleman from the University of Auckland for developing **R** 
from John Chambers' **S** programming language.
**R** is used to 
Thank you also to JJ Allaire, the founder and CEO of [RStudio](http://rstudio.com), 
and Hadley Wickham, mastermind of the `tidyverse` suite of packages,
without which we'd all just given up and done data science in Python instead.

Lastly, thank you to Yihui Xie for creating 
`knitr` which introduced *RMarkdown* as a way of embedding code in Markdown documents, 
and `bookdown` which added tools for technical and longer-form writing.
[Chester Ismay](http://chester.rbind.io) created the `thesisdown` package which,
together with `rticles` and `memor`, served as inspiration for this package. 
And special thanks to Ulrik Lyngs, 
who converted John McManigle and Sam Evans' adaptations of Keith Gillow's original \LaTeX\ template for writing an Oxford University DPhil thesis 
into an `oxforddown` *RMarkdown* template that serves as the basis for this skeleton.

These enormous contributions make theses and dissertations easier to write, share, and replicate.

\begin{flushright}
James Hollway \\
Geneva Graduate Institute \\
13 June 2020
\end{flushright}

---
####################
## Metadata       ##
####################
course: Mathematics of Ring-bearing
title: |
  Problem Set 1
code: MINT001 # Course code for filename.
date: "`r paste(Sys.Date())`" # Inserts today's date
authors: Gandalf the Grey, Frodo Baggins
# This is the YAML (YAML Ain't Markup Language) header that includes 
# metadata used to produce the document. 
# Be careful with spacing in this header!
# Two spaces at the start of the line create indentation,
# which embeds the parameter in a hierarchy.

#####################
## Bibliography    ##
#####################
bibliography: [references.bib, packages.bib]
csl: chicago-author-date.csl
nocite: '@*' # Adds all elements in bib file to bibliography

##########################
## Define Knit function ##
##########################
knit: iheiddown::problemset_pdf

#####################
## Output Options  ##
#####################
output: iheiddown::problemset_pdf
link-citations: true
documentclass: article
---

```{r, echo=FALSE}
# Set initial knitr options
knitr::opts_chunk$set(eval = TRUE, echo = FALSE,
                      fig.align = "center",
                      fig.asp = 0.7,
                      dpi = 300,
                      out.width = "80%",
                      fig.pos = "!H",
                      out.extra = "")
```

# Problem 1: Escaping the Shire

Solving problem sets will be a weekly ritual at IHEID if you are taking
quantitative courses at the Graduate Institute.`{iheiddown}`'s problem set
template lets you focus on solving the problem set rather than wasting time on
formatting [@iheiddown2020]. Furthermore, since your documents will be written
in RMarkdown, you won't need to learn the more complex Latex syntax.
Finally, it allows you to code and interpret the your results at the same time
which will again speed up your workflow!

# Problem 2: Hiding in forests

Your problem sets will contain some text, probably the solution to a
strange mathematical model and maybe even some pretty graphs. The good news is
that you can type that really easily in your RMarkdown file!

## Tables

The following example shows a simple way to estimate several models and
summarize them in a clear way using the
[`{modelsummary}`](https://vincentarelbundock.github.io/modelsummary/index.html)
package.

```{r Table, echo=TRUE, fig.align='center'}
####################
## Tables Example ##
####################

# Loading the required packages
library(modelsummary)
library(kableExtra)
library(gt)

#Extracting example data
url <- "https://vincentarelbundock.github.io/Rdatasets/csv/HistData/Guerry.csv"
dat <- read.csv(url)

# Creating a list of the different models
models <- list(
  "OLS 1"     = lm(Donations ~ Literacy + Clergy, data = dat),
  "Poisson 1" = glm(Donations ~ Literacy + Commerce,
                    family = poisson,
                    data = dat),
  "OLS 2"     = lm(Crime_pers ~ Literacy + Clergy, data = dat),
  "Poisson 2" = glm(Crime_pers ~ Literacy + Commerce,
                    family = poisson,
                    data = dat),
  "OLS 3"     = lm(Crime_prop ~ Literacy + Clergy, data = dat)
)

# Creating a summary of the different models
modelsummary(models)
```

## Graphs

```{r MpgGraph, echo=FALSE, fig.align='center'}
###################
## Graph Example ##
###################

library(ggplot2)
ggplot(mtcars, aes(mpg, wt)) +
  geom_point() +
  labs(x="Fuel efficiency (mpg)", y="Weight (tons)",
       title="Seminal ggplot2 scatterplot example",
       subtitle="A plot that is only useful for demonstration purposes",
       caption="Brought to you by {iheiddown}") + 
  theme_iheid()
```

# Problem 3: Resisting the power of the Ring

Writing equations is straightforward too! They follow the standard Latex
syntax as shown below. Also see
[this great guide](https://www.overleaf.com/learn/latex/Mathematical_expressions)
for a more comprehensive overview of the math syntax in Latex.

$$ E("Escaping"|"Magic") = \frac{a}{b}$$


# Problem 4: Melting things in volcanoes

Inserting images is easy! Place the image in your main folder and use the
following syntax (see the RMarkdown file).

![Ideal place for melting rings](volcano.jpg)

# Appendix:

Note that you can reference previous code chunks at the end of the code for full
transparency. This is a good way to avoid cluttering your main body with
code while still allowing your reader to see the code you executed to get your
results. Let us demonstrate this feature by inserting the un-evaluated code of 
all chunks used in this document.

```{r ref.label=knitr::all_labels(), echo=TRUE, eval=FALSE}
```

```{r pkgbib, echo=FALSE}
################################
## Citing all loaded packages ##
################################
knitr::write_bib(c(.packages(), "bookdown"), "packages.bib")
```

# References:
<!-- The bibliography is automatically generated here. -->

# Appendix: The Echoes of the Code{-}

```{=latex}
\markboth{Appendix}{Appendix}
```

The goal of this appendix is to echo the code you used in your thesis for a greater sense of transparency and replicability of your research. 
Note that `ref.labels` can be set to any label. 
Hence, you can filter the code you want replicated in the appendix by setting labels to the desired code chunks in the various chapters. 
See [this excellent resource](https://yihui.org/rmarkdown-cookbook/code-appendix.html) for more information.


This might be particularly useful when you perform model selection to output intermediary steps here instead of in the code to avoid cluttering your report. 

```{r get-labels, echo = FALSE}
labs <- knitr::all_labels()
labs <- setdiff(labs, c("setup", "get-labels"))
```

```{r all-code, ref.label=labs, eval=FALSE}
```

# Appendix: The Echoes of the Code redux{-}

Add as many appendices as you like.

---
title: A Better Reproducible Poster Title
author:
  - name: Gandalf the Grey
    affil: 1
    twitter: Gandalf
    email: GandalftheGrey@iheid.ch
    orcid: "0000-0002-1825-0097"
    main: true
affiliation:
  - num: 1
    address: Department of International Ring Study, Central University of Middle Earth
main_findings:
  - "Make **better posters** with RMarkdown + **{iheiddown}**."
  - '![](https://raw.githubusercontent.com/jhollway/iheiddown/main/man/figures/iheiddown.png){.main_pic}'
logoleft_name: '![](https://raw.githubusercontent.com/jhollway/iheiddown/main/man/figures/iheiddown.png){.main-img-left}'
logoright_name: '![](https://raw.githubusercontent.com/jhollway/iheiddown/main/man/figures/iheiddown.png){.main-img-right}'
output: 
  iheiddown::iheiddown_betterland:
    self_contained: false
    pandoc_args: --mathjax
    highlight: haddock
    number_sections: false
link-citations: true
bibliography: packages.bib
---

```{r, include=FALSE}
knitr::opts_chunk$set(results = 'asis',
                      echo = FALSE,
                      warning = FALSE,
                      tidy = FALSE,
                      message = FALSE,
                      fig.align = 'center',
                      out.width = "100%")
options(knitr.table.format = "html") 
```

```{r myplot, include=FALSE}
svg('myplot.svg')
plot(iris$Sepal.Length, iris$Sepal.Width)
dev.off()
```

# Introduction

This is the `iheiddown_betterport` template for the `{iheiddown}` [@iheiddown] package!
Based on the great `{iheiddown}` package, it provides the user with an IHEID
version of the template by default. The original `{iheiddown}` template was
inspired by the twitter thread of
[Mike Morrison](https://mobile.twitter.com/mikemorrison/status/1110191245035479041).

```{r, include=FALSE}
knitr::write_bib(c('iheiddown', 'posterdown',
                   'rmarkdown','pagedown'),
                 'packages.bib')
```

## Objectives

1. Pick a template layout.
2. Write/ create your poster content distraction free.
3. Let iheiddown do its thing!

# Methods

I will show here how to include poster elements that may be useful, such as an equation using mathjax:

$$
E = mc^2
$$

To reference a citation you can add your `.bib` file to the working directory and name it in the YAML metadata or generate an automated one as done here, then you only need to reference the label value in the `.bib` file. For example this package is built on top of the wonderful {pagedown} package and I will cite it at the end of this sentence using this in the rmd `[@R-pagedown]` [@R-pagedown].

To get a better understanding of how to include features like these please refer to the {iheiddown} [wiki](https://github.com/iheiddown/wiki).

**_Now on to the results!_**

<br>

# Results

Here you may have some figures to show off, bellow I have made a scatterplot with the infamous Iris dataset and I can even reference to the figure automatically like this, `Figure \@ref(fig:irisfigure)`, Figure \@ref(fig:irisfigure).

```{r, irisfigure, fig.cap='Here is a caption for the figure. This can be added by using the "fig.cap" option in the r code chunk options, see this [link](https://yihui.name/knitr/options/#plots) from the legend himself, [Yihui Xie](https://twitter.com/xieyihui).', out.width="80%"}
par(mar=c(2,2,0,1))
plot(x = iris$Sepal.Length,
     y = iris$Sepal.Width,
     col = iris$Species,
     pch = 19,
     xlab = "Sepal Length",
     ylab = "Sepal Width")
```

Maybe you want to show off some of that fancy code you spent so much time on to make that figure, well you can do that too! Just use the `echo=TRUE` option in the r code chunk options, Figure \@ref(fig:myprettycode)!

```{r myprettycode, echo=FALSE,collapse=TRUE, fig.cap='Boxplots, so hot right now!', fig.height=3.5, out.width="80%"}
#trim whitespace
par(mar=c(2,2,0,0))
#plot boxplots
boxplot(iris$Sepal.Width~iris$Species,
        col = "#ed2215", 
        border = "#800000",
        ylab = "Sepal Width (cm)",
        xlab = "Species")
```

How about a neat table of data? See, Table \@ref(tab:iristable):

```{r, iristable}
knitr::kable(
  iris[1:8,1:5], format = "html",
  caption = "A table made with the **knitr::kable** function.",
  align = "c", col.names = c("Sepal <br> Length",
                             "Sepal <br> Width",
                             "Petal <br> Length",
                             "Petal <br> Width",
                             "Species"),
  escape = FALSE)
```

# References

`r if(!knitr:::is_latex_output()) '# References {-}'`

<!-- 
You don't really need to alter this chapter unless you want to change the name of the bibliography section 
to 'Bibliography', 'Literature', or something similar.
Any references included in the chapters will be printed here automatically.
-->

<!-- This quiet code chunk serves as a custom style for the reference section and adds a custom header. Don't change it unless you really want to. -->
```{=latex}
\markboth{References}{References}
```

---
title: "Writing your thesis"
author: "Bernhard Bieri"
date: "`r Sys.Date()`"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{Writing your thesis}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r global.options, include = FALSE}
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>",
  fig.align = 'center',
  fig.width = 6,
  fig.height = 4
)
```

```{r setup, include=FALSE}
pkgs <- c("iheiddown", "magrittr", "ggplot2")
lapply(pkgs, library, character.only = TRUE)
```

`{iheiddown}`'s primary feature is to enable students of the Institute to write
their thesis in R-Markdown. It takes care of the annoying formatting process and
automates the most repetitive tasks a student faces when writing scholarly
documents. In short, `{iheiddown}` allows its users to focus on the *content*
rather than the *formatting* of a thesis.

This guide will show you how to get up and running and start writing your thesis
in R while providing you with helpful tips and tricks to make you familiar with
the workflow of writing your very own scholarly documents in R.

## Installation

The installation process is the same than for the thesis template. You'll need
the following software:

1. Install [R](https://cran.r-project.org) and [R-Studio](https://posit.co/)
2. Install a LATEX distribution:
    - [For MacOS](https://www.tug.org/mactex/)
    - [For Windows](https://miktex.org/)
    - [For Linux](https://www.tug.org/texlive/)
3. Install `{iheiddown}` by typing the following command
`install.packages("iheiddown") ` in the R-Studio console. 

Note: typing `remotes::install_github("jhollway/iheiddown")` will provide you
with the latest version from GitHub.

## Create your first thesis project

Creating your first thesis is easy! Let's look at how it is done. Before
we begin, we have to create a new R project by clicking on the file tab in the
top of the RStudio window and following the instructions of the prompt that
appears. Now that we have created an R project for our presentation, we can open
a new R-Markdown file. To do this click on the "plus file" logo in the top left
corner and then on "R-Markdown".

```{r, echo = FALSE, out.width="80%", fig.cap="Step 1: Open a project"}
  knitr::include_graphics("images/thesis/0-OpenProject.png", dpi = 144)
```

After you have done this, a little pop-up helper will appear. The first thing we
will do is to select the `{iheiddown}` template for our thesis. To do so,
click on the "From Template" option on the left and select the
"Thesis {iheiddown}" template. Now give your thesis a name and click
on "OK".

Important note! Name your project `index`. This makes sure that the main Rmd
file is called `index.Rmd` which is required to render your thesis with
our `{bookdown}` based rendering function. Don't worry though, you can rename
the folder to your project name after creating it.

```{r, echo = FALSE, out.width="80%", fig.cap="Step 2: Select a template"}
  knitr::include_graphics("images/thesis/1-CreateThesis.png", dpi = 144)
```

Congrats! You just created your first thesis project!

Hold on, this doesn't look anything like a Word processor!? To see your thesis,
you have to "knit" the code by clicking on the little "knit" button while 
viewing the `00-MyThesis.Rmd` file. This will run all the code chunks in every
chapter and convert the Markdown code to a correctly formatted PDF document that
you will find in the `\versions` folder of your project.

Take a moment to read through the generated PDF to get acquainted with the
`{R-Markdown}` syntax and to get a feel of the possibilities of `{iheiddown}`'s
thesis template. This first document is as much a tutorial as this vignette!


## Edit your thesis

This section will focus on giving you an overview of the elements of an
`{iheiddown}` thesis and give you a few tips and tricks to edit it.

### The different elements of a `{iheiddown}` thesis

After this initial preview, let's look at how the thesis project is structured
to better understand how to edit it. 

#### The index file

The index file contains two things: the YAML header and the preface of your
thesis. It is also the backbone of your thesis in the sense that this is where
you will want to knit your whole thesis from.

The YAML header is the place where the main options, metadata and formatting
parameters are set. You can set the title of your presentation here, add your
name, change the front matter of your thesis (abstract, acknowledgments, table
of content, etc.).

The second element in this file is the preface. The only crucial thing to know
here is that in order to create your package bibliography (the software you use
to render your thesis) you need to leave the first code chunk there.

#### The chapters

The chapters contain the meat of your thesis, this is where you will outline
your idea, run your analyses and draw your conclusions.

Chapters are structured in a similar way, so let us open the
`01-introduction.Rmd` chapter. In it, you will first find a YAML header that
where you can set various chapter level metadata and options.

Note that if for some reason you rename the chapter, you will need to specify
the new name in the YAML header too under the `input` option. Once you have done
this you can write away!

The last thing to know about individual chapters is that you can knit them
individually. This comes in handy when you want to generate only one part of
your thesis for preview purposes.

#### The appendix and the references files

These files are a bit special as you might notice when you open them. 

The `99-references.Rmd` file generates the bibliography. This happens
automatically, so you will most likely not need to alter this file. Just know
that you can set the title of the reference section in the first line.

The `98-appendix.Rmd` file allows you to showcase code, additional outputs and
more in a separate section to avoid unnecessarily cluttering the main body of
your thesis. This can be done by [referencing code chunks](https://yihui.org/rmarkdown-cookbook/reuse-chunks.html)
from your main body and printing the computations you did in your R chunks or 
by adding new ones.

#### The `_bookdown.yml` file

The `_bookdown.yml` file contains additional information for the YAML header
of the main `.Rmd` file. A standard user should not have to edit it. If for some
reason or another you still feel like it, you need to know that you can set
additional `.Rmd` subdirectories, set another output file than the standard
`\versions` file, and toggle the deletion of merged files after the knitting
process ended here.

#### The `\bib` folder

The bibliography folder contains two files; `packages.bib` and `references.bib`.
The former is automatically generated by the first code chunk in the `index.Rmd`
file and cites the packages you have loaded when running your code chunks.
You will not need to alter this.

On the other hand, the `references.bib` file is the place to dump the bibtex
citations that you will cite in your thesis.

#### The `\data` folder

The data folder is the place to put all the data that you use in the code chunk
of your analysis. Remember to keep it tidy so you can easily link data to
outputs down the line such as graphs and tables.

#### The `\figures` folder

The figures folder will contain all the graphical elements that you may want to
include in your thesis e.g. figures, graphs, or images. It also contains a file
named `SecretariatDocument.pdf` that you will need to replace with the one that
was handed to you by the PhD or Master's secretariat. Remember to rename the
file you got from the secretariat as `SecretariatDocument.pdf`. Otherwise
`{iheiddown}` will not recognize it.

#### The `\front-matter` folder

The front matter folder contains the front matter of your thesis. This is where
you will be able to edit the abbreviations part in the corresponding Latex file,
the acknowledgments section or the abstract of your thesis in their
respective `.Rmd` files.

#### The `\versions` folder

This is where you will find the pdf file after your thesis has been knitted by
`{iheiddown}`.

## Additional resources

Here is a list of additional links that will help you get familiar with our
`{iheiddown}` thesis template, `{bookdown}` and `Markdown` syntax.

- [R-Markdown Cookbook](https://yihui.org/rmarkdown-cookbook/)
- [Bookdown book](https://yihui.org/bookdown/)
- [Markdown guide](https://www.markdownguide.org/)

---
####################
## Metadata       ##
####################
title: |
  Transfiguration
code: MINT001
credits: 12
year: 2020--2021
semester: Fall
program: |
  Master of International Ring-bearers \
  Master of the International Fellowship of the Ring
# This is the YAML (YAML Ain't Markup Language) header that includes 
# metadata used to produce the document. 
# Be careful with spacing in this header!
# Two spaces at the start of the line create indentation,
# which embeds the parameter in a hierarchy.

####################
## Professor      ##
####################
prof: Gandalf the Grey
prof-email: gandalf.thegrey@graduateinstitute.ch
location: Zoom 123-456-7890
prof-office-hours: "[Fridays, 17--19](https://bit.ly/goog.ly)"

####################
## Assistant      ##
####################
ta: Frodo Baggins
ta-email: frodo.baggins@graduateinstitute.ch
ta-office-hours: By appointment

####################
## Course         ##
####################
description: |
  This course teaches everything you ever wanted
  to know about the Fellowship of the Ring. You will learn
  how to melt rings in volcanoes, evade Nazgûls, and not to trust Saruman.
aims: |
  This course has two main purposes.
  First, it provides a deeper understanding of resisting the Power of the Ring.
  Second, it applies these insights through practical exercises.
structure: |
  Extraordinarily, due to the novel coronavirus pandemic, 
  we will be moving this course online for the remainder of the semester.
materials: |
  There is no required textbook for this course.
  All materials can be found on Moodle.
evaluation: |
  Evaluation is by a combination of participation, term papers, and exam.
  
  **Participation (10%)**: This is about participation.
  
  **Papers (40%)**: This is about the term papers.
  
  **Exam (50%)**: This is about the exam.
policies: |
  *Auditing* is possible. Please contact me.
  
  *Grading* is according to the Swiss 1-6 scale.
  
  *Plagiarism* is not tolerated at the Graduate Institute. 
  If you are unsure, please contact the TA.
bibimport: |
  Are you using a bibliography manager like Zotero or Mendeley to manage your
  PDFs?
  [Click here](https://raw.githubusercontent.com/jhollway/iheiddown/main/inst/rmarkdown/templates/syllabus/skeleton/references.bib) to get the `.bib` file of this course to
  import it into your software of choice!

#####################
## Bibliography    ##
#####################
bibliography: references.bib
csl: geneva-syllabus.csl

##########################
## Define Knit function ##
##########################
knit: iheiddown::syllabus_pdf

#####################
## Output Options  ##
#####################
output: iheiddown::syllabus_pdf
# Set to true if you want anchors to the rendered bibliography
link-citations: false 
draft: true
documentclass: article
---

```{r, echo = FALSE}
startdate <- as.Date("2020-09-14")
```

## `r advdate(startdate, 1)`: Inheriting a Ring

Inheriting a ring can lead to a great adventure!

*Required readings*

@Darwin1859

[*Additional readings*]{color="gray"}

[@iheiddown2020]{color="gray"}

\newpage

##  `r advdate(startdate, 2)`: Escaping the Shire

*Required readings*

@Satchell2009

##  `r advdate(startdate, 3)`: Fleeing from the Nazgûl

##  `r advdate(startdate, 4)`: Meeting Strider

##  `r advdate(startdate, 5)`: Arrival in Rivendell

##  `r advdate(startdate, 6)`: On the road to Mordor

---
title: Results
author: Author
chapter: 4
in_context: False
knit: iheiddown::chapter_pdf
output: iheiddown::chapter_pdf
---

\setcounter{chapter}{3}
# Results {#results}

## An intro to R chunks

One of the most useful parts of _RMarkdown_ is the ability to weave or 'knit' text 
(as we've seen in the previous three chapters)
together with the code that produces tables and graphics for your final document.
This has various advantages such as:

- *coherence*: for you, having your analysis and text together means keeping a coherent story together about why you did the analysis you did, how you got to your results, and what your interpretation of these results is
- *amendability*: this gives you an opportunity to update the code, for example by filtering the data in a different way, and rerun the code to see how any statistics, tables or graphs related to the data may have changed
- *reproducibility*: this also, importantly, supports a reproducible workflow such that you, or others, can rerun and test the code at a later point

To 'knit' such text and code together, code for particular graphs or tables should first be inserted into the text in 'chunks'.
These chunks are opened with three backticks and closed in a new line with another three backticks.
The code that produces the desired output is included between these lines, 
which can include comments etc.
A key part of these chunks are the chunk parameters,
which are included in braces immediately following the first set of backticks.
The first parameter indicates the programming language.
The second parameter, 
which is optional and should be separated from the first parameter only by a space,
is a chunk label.
It is important that this chunk label includes no spaces and is unique to this chunk.
Then, separated by commas, are any additional parameters included.
In the figure below, two examples are included:
whether or not the code itself should be shown (`echo`)
and whether or not the code should be evaluated or run (`eval`).
Other parameters that we will see later include figure width, captions, etc.^[More information is available at [https://yihui.org/knitr/options/](https://yihui.org/knitr/options/).]

```{r chunk-parts, results="asis", echo=FALSE, fig.cap="Chunk parts", out.width="\\textwidth"}
knitr::include_graphics("figures/chunk-parts.png")
```

In the code chunk shown in Figure \@ref(fig:chunk-parts),
we can see that it is loading a package library.
Functions and objects loaded or created in earlier chunks are cached by default and
thus held on to for use in later chunks.
It is therefore quite common to have a chunk early on in your chapter (or even your whole dissertation)
that loads a number of the packages you need later on.
As an example, below is a short code chunk that loads a set of **R** packages that we are going to rely on
for the rest of this chapter.

```{r load_pkgs, message=FALSE}
# Load packages
library(dplyr)
library(ggplot2)
library(knitr)
```

When you click the **Knit** button above in RStudio a document will be generated that includes both content 
as well as the output of any embedded **R** code chunks within the document.
If you need a graphic or tabular material to be part of the text, you can just put it inline. 
If you need it to appear in the list of figures or tables, it should be placed in a code chunk.

In the remainder of this chapter,
we will see how to use code chunks to include figures, load and summarise data, and present results from your analysis.

## Including external figures

First, we will treat how to include figures in _RMarkdown_ in more detail.
If your thesis has a lot of figures, _RMarkdown_ might behave better for you than your usual word processor,
which can have a tendency to .
One perk is that it will automatically number the figures accordingly in each chapter.
You'll also be able to create a label for each figure, add a caption, and then reference the figure in a way similar to what we saw with tables earlier.
If you label your figures, you can move the figures around and _RMarkdown_ will automatically adjust the numbering for you.
No need for you to remember!
So that you don't have to get too far into \LaTeX\ to do this, a couple **R** functions have been created for you to assist.
You'll see their use below.

### Numbering and labelling figures

You don't need to number figures in _RMarkdown_; it'll do it automatically.
And captioning a figure is awfully easy too.
In the **R** chunk below, we will load in a picture that is stored as `iheid.png` in our `figures` directory.
The `include_graphics()` function is from the `{knitr}` package, that does most of the heavy lifting here.
We'll label the chunk 'iheidlogo' so that we can refer back to it later,
and give the figure the caption "IHEID logo".
You will see that here you do not need to include the parameter `echo=FALSE`,
as the code including the figure is hidden by default.

```{r iheidlogo, fig.cap="IHEID logo", out.width="50%", fig.align='center'}
include_graphics(path = "figures/iheid.png")
```

### Referencing figures

Referencing figures in the text should be done with a little reference to the chunk label
so that it will always refer to the right figure number, 
even if you add additional figures and plots before it.
To reference the IHEID logo use a backslash, at-symbol, and then in parentheses `fig:chunk-label`,
like so `\@ref(fig:iheidlogo)`.
Usually some descriptor like "Figure", "Fig.", "Illustration" or other is added before this reference,
so that it reads something like Figure \@ref(fig:iheidlogo).
Note that the reference is hyperlinked in the resulting PDF, 
so that you can click on it to take you to the page where the original figure is printed.

### Resizing figures

It is common to resize external image files so that they fit the format of the text.
The most common way to do this was already demonstrated in the code chunk for Figure \@ref(fig:chunk-parts) above.
There we used the parameter `out.width="\\textwidth"` to, in this case, shrink the image to the width of the text,
but this same parameter specification would also expand an image to fit the width of the text where possible.

Another option is the `out.extra` chunk option. 
This can be used to shrink or expand an image loaded from a file more specifically by specifying `"scale= "`.
Here we use the graph stored in the "subdivision.pdf" file, again found in the `figures` subdirectory.
The output can be found in Fig. \@ref(fig:subd).

```{r subd, fig.cap="Subdiv. graph", out.extra="scale=0.75"}
include_graphics("figures/subdivision.pdf")
```

We can also use the `out.extra` chunk option to enlarge figures, 
and even to rotate them any number of degrees around its axis.
In Figure \@ref(fig:subd2), we see an example where Figure \@ref(fig:subd) has been enlarged and flipped upside down.

```{r subd2, out.extra="angle=180, scale=1.1", fig.scap="Subdiv. graph flipped", fig.cap="A Larger Figure, Flipped Upside Down"}
include_graphics("figures/subdivision.pdf")
```

If you look closely at the chunk options,
you will also see that two different captions have been provided.
The `fig.scap` is a short caption that overrides the main caption, `fig.cap`, in the table of contents.
This can be very useful where, for example, you need to describe the figure in a caption over several lines,
details that do not need to be presented in the table of contents.

### Placing figures

One thing that may be annoying is the way _RMarkdown_ handles "floats" like tables and figures (it's really \LaTeX's fault). 
\LaTeX\ will try to find the best place to put your object based on the text around it and,
until you're really, truly done writing, it is best to just leave it where it lies. 
There are some optional arguments specified in the options parameter of the `label` function.
If you need to shift your figure around, it might be good to look [here](https://en.wikibooks.org/wiki/LaTeX/Floats,_Figures_and_Captions) (you can click on the word 'here') on tweaking the options argument.

Spacing out your chunks between paragraphs can help, 
as it can give \LaTeX\ more options to find a suitable home for the figure or table,
as \LaTeX\ would otherwise try and keep all the text together, saving the image for later.
A last trick is to write `\clearpage` directly in your _RMarkdown_ document.
This gives \LaTeX\ a chance to catch up with all the 'floats' it has accumulated,
and starts a new page.

\clearpage 

## Loading and exploring data

Sometimes it is not an existing image that must be imported,
but instead you wish to create a table or plot of some data that you have imported.
In this section, we're going to very quickly cover how to import internal and external data,
how to manipulate and summarise the data, create plots from that data,
and tabulate inferential results from that data.

### Importing data {#import-data}

In some cases, the data you need might be available already in an **R** package.
An example below is a very short code chunk that summarises a dataset that is built into **R**.
Here it is particularly easy, as we do not even need to load the data (it is loaded by default).

```{r cars}
summary(cars)
```

Othertimes you may need to load the data first before summarising it,
with the function `data()`.
There are an increasing number of data packages for **R** available,
including several on a range of international and development topics.

The other option is to import data that resides in a file outside of **R**.
Included in this template is a file called `flights.csv`.
This file includes a subset of the larger dataset of information about all flights that departed from Seattle and Portland in 2014.^[More information about this dataset and its **R** package is available at [https://github.com/ismayc/pnwflights14](https://github.com/ismayc/pnwflights14).] 
This subset includes only Portland flights and only rows that were complete with no missing values. 
Merges were also done with the `airports` and `airlines` data sets in the `pnwflights14` package 
to get more descriptive airport and airline names.
We can load in this data set using the following commands:

```{r load_data}
# flights.csv is in the data directory
flights <- read.csv("data/flights.csv")
```

The data is now stored in the data frame called `flights` in the cached environment for this _RMarkdown_ document in **R**.
To get a better feel for the variables included in this dataset we can use a variety of functions. 
Here we can see the dimensions (rows by columns) and also the names of the columns.

```{r str}
dim(flights)
names(flights)
```

Another good idea is to take a look at the dataset in table form.
With this dataset having more than 20,000 rows, we won't explicitly show the results of the command here,
so we'll use the `eval=FALSE` chunk option to make sure the following is not run when you 'knit' the document.
Still, you can press the green play button at the right of the chunk to run the chunk on demand,
bringing up a new tab showing the data.

```{r view_flights, eval=FALSE}
View(flights)
```

\clearpage

### Manipulating and summarising data

While not required, it is highly recommended you use the `dplyr` package to manipulate and summarize your data set as needed.
It uses a syntax that is easy to understand using chaining or 'pipe' operations (`%>%`).
Below I've created a few examples of using `dplyr` to get information about the Portland flights in 2014.
The example we show here does the following:

- Selects only the `carrier_name` and `arr_delay` from the `flights` dataset and then assigns this subset to a new variable called `flights2`.
- Using `flights2`, we determine the largest arrival delay for each of the carriers.

```{r max_delays}
flights2 <- flights %>%
  select(carrier_name, arr_delay)
max_delays <- flights2 %>%
  group_by(carrier_name) %>%
  summarize(max_arr_delay = max(arr_delay, na.rm = TRUE))
```

A useful function in the `knitr` package for making nice tables in _RMarkdown_ is called `kable`.  
It is much easier to use than manually entering values into a table by copying and pasting values into Excel or \LaTeX\.
This again goes to show how nice reproducible documents can be! 
The chunk option `results="asis"` makes sure the table is produced, not the code to create the table.
Tables created with the `kable()` function (in `{knitr}`) can be extended in many useful (and pretty) ways
with the recommended `{kableExtra}` package.

```{r maxdelays, results="asis"}
kable(max_delays,
  col.names = c("Airline", "Max Arrival Delay"),
  caption = "Maximum Delays by Airline",
  caption.short = "Max Delays by Airline",
  longtable = TRUE,
  booktabs = TRUE
)
```

Note that instead of adding the caption details in the chunk options, we will be adding this in the `kable()` function,
which then passes this on up.
The `caption.short` argument is used to include a shorter title to appear in the List of Tables.
The last two options make Table \@ref(tab:maxdelays) a little easier-to-read.^[Note that we can create references/links to tables using a very similar syntax here to that with figures above. We can preface the reference with "Table" or "Tab." or so, and then create the reference with the format `\@ref(tab:chunk-label)`.]

We can further look into the properties of the largest value here for Alaska Airlines Inc.
To do so, we can isolate the row corresponding to the arrival delay of 70 minutes for Alaskan in our original `flights` dataset.
We see that the flight occurred on January 1st and departed a little after 1:30 am on its way to Anchorage.  

```{r max_props}
flights %>%
  dplyr::filter(
    arr_delay == 70,
    carrier_name == "Alaska Airlines Inc."
  ) %>%
  select(-c(
    month, day, carrier, dest_name, hour,
    minute, carrier_name, arr_delay
  ))
```

### Creating plots

Once data has been loaded or imported and manipulated or filtered as required,
a common task is to visualise some key dimensions of the data to inform the reader.
Here the package `{ggplot2}` plays nicely with `{dplyr}` and other `{tidyverse}` packages.
`{ggplot2}` produces beautiful, high-quality academic visuals,
and has been extended with a huge range of add-ons for a very broad variety of visualisation styles
no matter what kind of data you have.

We're going to continue playing with the `flights` dataset from Chapter \@ref(import-data).
First, let us show how we can visualize the arrival delay of all departing flights from Portland on March 3rd against time of departure.
Note that once you open the plotting function with `ggplot()`,
additional elements are chained not with the pipe operator `%>%` but `+`.
Considerably more help than I can offer here on how to use `ggplot()` can be found online.

```{r march3plot, fig.height=3, fig.width=6}
flights %>%
  dplyr::filter(month == 3, day == 3) %>%
  ggplot(aes(x = dep_time, y = arr_delay)) +
  geom_point()
```

Next Figure \@ref(fig:delaysboxplot) presents a bar graph with the mean flight departure delays by airline from Portland for 2014.
A table linking these carrier codes to airline names is available at [https://github.com/ismayc/pnwflights14/blob/master/data/airlines.csv](https://github.com/ismayc/pnwflights14/blob/master/data/airlines.csv).

```{r delaysboxplot, warnings=FALSE, messages=FALSE, fig.cap="Mean Delays by Airline", fig.width=6}
mean_delay_by_carrier <- flights %>%
  group_by(carrier) %>%
  summarize(mean_dep_delay = mean(dep_delay))
ggplot(mean_delay_by_carrier, aes(x = carrier, y = mean_dep_delay)) +
  geom_bar(position = "identity", stat = "identity", 
           fill = iheiddown::iheid_palette("IHEID", 1)) +
  theme_minimal()
```

You don't have to use `{ggplot2}` though.
For example, here is a way to use the base **R** graphics package to produce a plot using the built-in `pressure` dataset:

```{r pressure, echo=FALSE, cache=TRUE, fig.height=3, fig.width=5}
plot(pressure)
```

### Tabulating inferential results

Another common task researchers have is the presentation of results obtained from applying various statistical methods to their data.
Since **R** makes available a very broad range of statistical methods, 
and all too often these output objects in different structures and formats, 
there is unfortunately no single package that reliably and prettily prints results.
Still, I can offer a few suggestions here that cover as much as possible,
in addition to `{kable}` and `{kableExtra}` mentioned above.

- [`{stargazer}`](https://cran.r-project.org/web/packages/stargazer/vignettes/stargazer.pdf) for well-formatted regression tables, with multiple models side-by-side, as well as for summary statistics tables, data frames, vectors and matrices.
- [`{xtable}`](https://cran.r-project.org/web/packages/xtable/vignettes/xtableGallery.pdf) offers a straightforward but extensible framework.
- [`{memisc}`](http://www.martin-elff.net/software/memisc/) provides tools for the management of survey data, as well as the creation of tables of summary statistics and model estimates.
- [`{Hmisc}`](https://hbiostat.org/R/Hmisc/) for data description and predictive modeling.
- [`{finalfit}`](https://finalfit.org/articles/export.html#pdf-via-knitrr-markdown) brings together the day-to-day functions we use to generate final results tables and plots when modelling.
- [`{tableone}`](https://github.com/kaz-yos/tableone) i.e., description of baseline patient characteristics.
- [`{flextable}`](https://davidgohel.github.io/flextable/) provides a framework for easily create tables for reporting and publications (PDF documents only with package `{pagedown}`).
- [`{huxtable}`](https://hughjonesd.github.io/huxtable/) creates LaTeX and HTML tables with a friendly, modern interface.
- [`{texreg}`](https://cran.r-project.org/web/packages/texreg/vignettes/texreg.pdf)
- [`{apsrtable}`](https://cran.r-project.org/web/packages/apsrtable/apsrtable.pdf)
- [`{arsenal}`](https://mayoverse.github.io/arsenal/)

I (James Hollway) would welcome any feedback on any other packages you find useful (more are being released all the time),
and which of these worked for your purposes.

### Tables from external data

In addition to the tables that can be automatically generated from data in **R**, you can also create tables directly using _pandoc_. 
This might be useful if you don't have values specifically stored in **R**, but you'd like to display them in table form.  
Below is an example.  
Pay careful attention to the alignment in the table and hyphens to create the rows and columns.
More information is available at [https://pandoc.org/README.html#tables](https://pandoc.org/README.html#tables).

----------------------------------------------------------------------------------
  Factors                    Correlation between Parents & Child      Inherited
------------------------- ----------------------------------------- --------------
  Education                                -0.49                         Yes
  
  Socio-Economic Status                     0.28                        Slight   
  
  Income                                    0.08                          No
  
  Family Size                               0.18                        Slight
  
  Occupational Prestige                     0.21                        Slight
------------------------- ----------------------------------------- --------------
Table: (\#tab:inher) Correlation of Inheritance Factors for Parents and Child 

The addition of the `(\#tab:inher)` option to the end of the table caption allows us to then make a reference to Table `\@ref(tab:label)`. 
Note that this reference could appear anywhere throughout the document after the table has appeared.  

---
title: Theory
author: Author
chapter: 2
in_context: False
knit: iheiddown::chapter_pdf
abstract: |
  This is an example of a chapter abstract.
  Ordinarily this would only be used for paper-based dissertations.
  All you need to do is add an 'abstract' line to this metadata header,
  and fill it in with your (paper) abstract.
  It is currently ignored when the entire dissertation is compiled,
  but is printed when just the chapter is compiled.
output: iheiddown::chapter_pdf
---

\setcounter{chapter}{1}
# Theory {#theory}

## Referencing

Your dissertation, and perhaps your theory/literature review chapter in particular,
will likely have plenty of citations.
Indeed, you will probably accumulate an armful of sources.
This section outlines how to assemble a bibliography and cite in text.

### Assembling a bibliography

_RMarkdown_ uses [_pandoc_](https://pandoc.org/) to build its bibliographies.
^[One nice feature of this is that, unlike using straight \LaTeX\, you won't need to do a second compile to load in references.]
*pandoc* (and \LaTeX\) rely on one or more external bibliography databases that contain all the bibliographic information
that you may use in your thesis.
In the end though, when it builds your bibliography, 
it will only create an entry for those items that you actually cite.

The required format for these bibliography database files is **BibTeX**.
**BibTeX** files are stored in a plain text file with the .bib extension.
See [this link](https://www.economics.utoronto.ca/osborne/latex/BIBTEX.HTM) for more.
I have placed an example file under the `/bib/` folder.
You can simply replace this with your own file under the same name,
or point to your file instead by changing the correct field
in the YAML header in the main .Rmd file.

There are a variety of tools available for creating these files.
For example, you may want to consider using the free and easy-to-use tool called Zotero.  
Our wonderful librarians have created documentation on [how to use Zotero](https://libguides.graduateinstitute.ch/zotero/home).

### Citing with `citr`

After creating your personal bibliographic database,
you can cite these entries in your dissertation with an `@` symbol, 
followed by the correct, unique identifier for that entry.
Let's take for example the `Darwin1859` entry that appears in the `references.bib` file in the `bib` folder.  

Standard parenthetical citations can be indicated with square brackets [@Darwin1859].
Without them, you will get a text citation.
For example, @Darwin1859 said some smart things.
If you wish to drop the name, 
say because you wish to replace it with something more fitting in the context,
you could say that Darwin's -@Darwin1859 theory of evolution is brilliant.

To cite multiple entries together, you can just concatenate the entries, 
separated by semi-colons.
For example, this package [@iheiddown2020] very much builds and relies upon the excellent work of others [@bookdown2016; @solomon2020].

You can also add page numbers and notes.
For example, you should start reading a book from the first page [@Darwin1859, p. 1],
though often all of them are good [@Darwin1859, pp. 1-502].
These need not be page numbers, but could be other suffixes.
You can add prefixes too [see @bookdown2016; cf. @solomon2020].

A more efficient way for entering these into your documents is by using the R package `citr`.
The `citr` package includes an 'addin' for RStudio that you can bind a keyboard shortcut to,
and that raises a search window where you can type author, year, or title information in to to find the required entry/ies.
It is enormously useful, particularly as your bibliography gets larger.
If you'd like to learn more, see [the README of its GitHub account](https://github.com/crsh/citr).

![Citing with citr](../figures/citr.png){ width=100%, height=45% }


\newpage

### Tips for bibliographies

- Like with thesis formatting, the sooner you start compiling your bibliography for something as large as thesis, the better. 
Typing in source after source is mind-numbing enough; do you really want to do it for hours on end in late May? 
Think of it as procrastination.
- The cite key (a citation's label) needs to be unique from the other entries.
- When you have more than one author or editor, you need to separate each author's name by the word "and" e.g. `Author = {Noble, Sam and Youngberg, Jessica},`.
- Bibliographies made using BibTeX (whether manually or using a manager) accept \LaTeX\ markup, so you can italicize and add symbols as necessary.
- To force capitalization in an article title or where all lowercase is generally used, bracket the capital letter in curly braces.
- You can add an iheiddown citation.^[@iheiddown2020] 

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/problemset_pdf.R
\name{problemset_pdf}
\alias{problemset_pdf}
\title{Creates an R Markdown PDF Problem Set document}
\usage{
problemset_pdf(input, ...)
}
\arguments{
\item{input}{The name of the .Rmd file to serve as input.}

\item{...}{Instructions passed to the function from a correctly specified
.Rmd document}
}
\value{
A modified \code{pdf_document} based on the IHEID Problem Set LaTeX
template, automatically named by course and date.
}
\description{
This is a function called in output in the YAML of the driver Rmd file
to specify using the IHEID Problem Set LaTeX template file.
}
\examples{
\dontrun{
output:
  iheiddown::problemset_pdf:
    input: "Untitled.Rmd"
    # Replace with whatever the name of this file is, e.g. "MINT001.Rmd"
}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dates.R
\name{advdate}
\alias{advdate}
\title{Advance dates by week}
\usage{
advdate(startdate, week)
}
\arguments{
\item{startdate}{The first date in the series (e.g. first day of class).}

\item{week}{The number of weeks into the series.
Week 1 is the first date in the series.}
}
\value{
A vector of dates in the format "dd mmm" in parentheses.
}
\description{
This function takes a start date, e.g. of a course,
and advances it by a number of weeks.
This function is used in the syllabus template.
}
\examples{
advdate("2021-06-23", 1:3)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/palettes.R
\docType{data}
\name{iheid_palettes}
\alias{iheid_palettes}
\title{Complete list of palettes}
\format{
An object of class \code{list} of length 3.
}
\usage{
iheid_palettes
}
\description{
Use \code{\link{iheid_palette}} to construct palettes of desired length.
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/poster_html.R
\name{posterdown_html}
\alias{posterdown_html}
\alias{iheiddown_poster}
\alias{iheiddown_betterland}
\alias{iheiddown_betterport}
\title{Posterdown inspired HTML posters}
\source{
\href{https://github.com/brentthorne/posterdown}{\code{{Posterdown}}}
}
\usage{
iheiddown_poster(
  ...,
  template = system.file("rmarkdown", "templates", "iheiddown_poster", "resources",
    "template.html", package = "iheiddown"),
  css = NULL
)

iheiddown_betterland(
  ...,
  template = system.file("rmarkdown", "templates", "iheiddown_betterland", "resources",
    "template.html", package = "iheiddown"),
  css = NULL
)

iheiddown_betterport(
  ...,
  template = system.file("rmarkdown", "templates", "iheiddown_betterport", "resources",
    "template.html", package = "iheiddown"),
  css = NULL
)
}
\arguments{
\item{...}{Additional arguments to \code{rmarkdown::html_document}}

\item{template}{Additional argument passed to \code{pagedown::poster_relaxed}.
IHEID poster templates by default.}

\item{css}{Additional argument passed to \code{pagedown::poster_relaxed}.
NULL by default.}
}
\value{
R Markdown output format to pass to
\code{\link[rmarkdown:render]{rmarkdown::render()}}
}
\description{
These functions render different versions of the original \code{{posterdown}}
templates with a little IHEID twist to them. All exports are in HTML format.
You can save them by printing them to PDF via a modern browser.

The output format \code{poster_betterland()} mimics the style of the
BetterPoster movement from twitter with an IHEID twist.

The output format \code{poster_betterport()} mimics the style of the
BetterPoster movement from twitter with an IHEID twist.
}
\examples{
\dontrun{
file <- file.path(tempdir(),"foo.rmd")
rmarkdown::draft(file, template="iheiddown_poster", package="iheiddown")
}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/theme.R
\name{theme_iheid}
\alias{theme_iheid}
\title{A ggplot2 theme for IHEID style plots. Adapted from Hrbrmstr's ipsum theme.}
\usage{
theme_iheid(
  base_family = "sans",
  base_size = 11.5,
  plot_title_family = base_family,
  plot_title_size = 18,
  plot_title_face = "bold",
  plot_title_margin = 10,
  subtitle_family = base_family,
  subtitle_size = 12,
  subtitle_face = "plain",
  subtitle_margin = 15,
  strip_text_family = base_family,
  strip_text_size = 12,
  strip_text_face = "plain",
  caption_family = base_family,
  caption_size = 9,
  caption_face = "italic",
  caption_margin = 10,
  axis_text_size = base_size,
  axis_title_family = subtitle_family,
  axis_title_size = 9,
  axis_title_face = "plain",
  axis_title_just = "rt",
  plot_margin = margin(30, 30, 30, 30),
  grid_col = "grey85",
  grid = TRUE,
  axis_col = iheid_palette("IHEID")["IHEIDBlack"],
  axis = FALSE,
  ticks = FALSE
)
}
\arguments{
\item{base_family, base_size}{base font family and size}

\item{plot_title_family, plot_title_face, plot_title_size, plot_title_margin}{plot title family, face, size and margi}

\item{subtitle_family, subtitle_face, subtitle_size}{plot subtitle family, face and size}

\item{subtitle_margin}{plot subtitle margin bottom (single numeric value)}

\item{strip_text_family, strip_text_face, strip_text_size}{facet label font family, face and size}

\item{caption_family, caption_face, caption_size, caption_margin}{plot caption family, face, size and margin}

\item{axis_text_size}{font size of axis text}

\item{axis_title_family, axis_title_face, axis_title_size}{axis title font family, face and size}

\item{axis_title_just}{axis title font justification, one of \verb{[blmcrt]}}

\item{plot_margin}{plot margin (specify with \code{ggplot2::margin()})}

\item{grid_col, axis_col}{grid & axis colors; both default to \verb{#cccccc}}

\item{grid}{panel grid (\code{TRUE}, \code{FALSE}, or a
combination of \code{X}, \code{x}, \code{Y}, \code{y})}

\item{axis}{add x or y axes? \code{TRUE}, \code{FALSE}, "\code{xy}"}

\item{ticks}{ticks if \code{TRUE} add ticks}
}
\value{
Themes the current ggplot to current IHEID guidelines.
}
\description{
A ggplot2 theme for IHEID style plots. Adapted from Hrbrmstr's ipsum theme.
}
\examples{
library(ggplot2)
library(dplyr)

# seminal scatterplot
ggplot(mtcars, aes(mpg, wt)) +
  geom_point() +
  labs(x="Fuel efficiency (mpg)", y="Weight (tons)",
       title="Seminal ggplot2 scatterplot example",
       subtitle="A plot that is only useful for demonstration purposes",
       caption="Brought to you by the letter 'g'") +
  theme_iheid()

# seminal bar chart
count(mpg, class) \%>\%
  ggplot(aes(class, n)) +
  geom_col() +
  geom_text(aes(label=n), nudge_y=3) +
  labs(x="Fuel efficiency (mpg)", y="Weight (tons)",
       title="Seminal ggplot2 bar chart example",
       subtitle="A plot that is only useful for demonstration purposes",
       caption="Brought to you by the letter 'g'") +
  theme_iheid(grid="Y") +
  theme(axis.text.y=element_blank())
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/bibstats.R
\name{bibstats}
\alias{bibstats}
\alias{percent_female}
\alias{mean_year}
\alias{mean_pages}
\alias{total_pages}
\title{Reporting bibliographic statistics}
\usage{
percent_female(bib_file, rmd_file, by = c("author", "publication"))

mean_year(bib_file, rmd_file)

mean_pages(bib_file, rmd_file)

total_pages(bib_file, rmd_file)
}
\arguments{
\item{bib_file}{A .bib file for the project.
If not given, the functions will search for a .bib file in the folder
associated with the file the source editor has open.}

\item{rmd_file}{A .rmd file
If not given, the functions will check to see whether the
current file open in the source editor is an .rmd file,
and if so use that.}

\item{by}{A string in c("author", "publication") which determines if the
percentage of female authors is computed across all papers or the percentage
represents the proportion of papers written by at least one woman.}
}
\value{
Prints a summary statistic (e.g. mean or proportion)
}
\description{
These functions are useful for calculating salient statistics
on the bibliographies used for dissertations or syllabi. They include the
following functions/metrics:
}
\details{
\describe{
\item{\code{percent_female()}}{Displays the percentage of authors in a
\code{.bib} file that are female. See the \code{{gender}} package for more details.}
\item{\code{mean_year()}}{Displays the average year of publication of the items
in a given \code{.bib} file.}
\item{\code{mean_pages()}}{Displays the average number of pages of the items
in a given \code{.bib} file.}
\item{\code{total_pages()}}{Displays the total number of pages of all items
in a given \code{.bib} file.}
}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/palettes.R
\name{iheid_palette}
\alias{iheid_palette}
\title{An IHEID palette generator}
\source{
Adapted from
\url{https://github.com/karthik/wesanderson/blob/master/R/colors.R}
}
\usage{
iheid_palette(name, n, type = c("discrete", "continuous"))
}
\arguments{
\item{name}{Name of desired palette. Current choices are:
\code{IHEID}, \code{Centres}, and \code{SDGs}.}

\item{n}{Number of colors desired. If omitted, uses all colours.}

\item{type}{Either "continuous" or "discrete". Use continuous if you want
to automatically interpolate between colours.}
}
\value{
A vector of colours.
}
\description{
These are a few color palettes useful for members of the  Geneva Graduate Institute.
This function calls one of three official palettes in
\code{\link{iheid_palette}}: for the Institute, for the Centres, and for the
SDGs.
}
\examples{
iheid_palette("IHEID")
iheid_palette("Centres")
iheid_palette("SDGs")

# If you need more colours than normally found in a palette, you
# can use a continuous palette to interpolate between existing
# colours
pal <- iheid_palette(21, name = "Centres", type = "continuous")
image(volcano, col = pal)
}
\keyword{colors}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/bookdown_profile.R
\name{bookdown_profile}
\alias{bookdown_profile}
\title{Manage iheiddown profile}
\usage{
bookdown_profile()
}
\value{
Opens or creates a bookdown profile YAML file for the current thesis.
}
\description{
This RStudio Addin opens up the ~/_bookdown.yml file for
users to edit. If the file doesn't exists, it will create one.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/count_words.R
\name{countwords}
\alias{countwords}
\alias{count_words}
\alias{count_words2}
\title{A function for counting words in an Rmarkdown document.}
\usage{
count_words(file)

count_words2(file)
}
\arguments{
\item{file}{A path to a .Rmd file}
}
\value{
A scalar representing the number of words in the document.
}
\description{
This function takes a path to a .Rmd file and returns a word count.
For best results each sentence should start on a new line.
Inline code chunks should also start on a new line.
}
\examples{
rmarkdown::draft(file = "test", template = "html_vignette",
package = "rmarkdown", create_dir = TRUE, edit = FALSE)
iheiddown::count_words("test/test.Rmd")
unlink("test", recursive = TRUE)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/thesis_pdf.R
\name{chapter_pdf}
\alias{chapter_pdf}
\title{Creates an R Markdown PDF Thesis chapter}
\usage{
chapter_pdf(input, ...)
}
\arguments{
\item{input}{Rmd input file that will be processed by the function.}

\item{...}{Instructions passed to the function from a correctly specified
.Rmd document}
}
\value{
A modified \code{pdf_document} based on the IHEID Thesis LaTeX
template
}
\description{
This function can be used in the header of each constituent chapter of an
IHEID thesis to output a draft version of the chapter for proofreading or
sending to your supervisor.
}
\examples{
\dontrun{
knit: iheiddown::chapter_pdf
}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/thesis_pdf.R
\name{thesis_pdf}
\alias{thesis_pdf}
\title{Creates an R Markdown PDF Thesis document}
\usage{
thesis_pdf(input = ".", ...)
}
\arguments{
\item{input}{Rmd input file that will be processed by the function.}

\item{...}{Instructions passed to the function from a correctly specified
.Rmd document}
}
\value{
A modified \code{pdf_document} based on the IHEID Thesis LaTeX
template
}
\description{
This is a function called in output in the YAML of the driver Rmd file
to specify using the IHEID Thesis LaTeX template file.
}
\examples{
\dontrun{
knit: iheiddown::thesis_pdf
}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/preview.R
\name{preview}
\alias{preview}
\alias{preview_start}
\alias{preview_stop}
\title{Previewing rmarkdown documents}
\usage{
preview_start(file_path, ...)

preview_stop(which = NULL)
}
\arguments{
\item{file_path}{The input Rmd file path (if missing and in RStudio, the
current active document is used).}

\item{...}{Additional arguments passed to
\code{rmarkdown::\link[rmarkdown]{render}()}.}

\item{which}{An integer vector of the server IDs;
by default, IDs of all existing servers in the current R session obtained
from \code{daemon_list()}, i.e., all daemon servers will be stopped by default.}
}
\value{
Starts serving the current files to RStudio's Viewer pane.

Stops serving the current files to RStudio's Viewer pane.
}
\description{
Use the \pkg{servr} package to continuously serve and reload
the Rmd document. Run \code{preview_start()} function while viewing the Rmd
panel of your presentation. To stop the server, run \code{preview_stop()}.
}
\references{
xaringan
}
